'use strict';

var index = require('./index-BTBT6v3v.js');
var mdi = require('./mdi-D4fs5l1W.js');

const cAccordionItemCss = "html{box-sizing:border-box}body{margin:0}*,*:before,*:after{box-sizing:inherit;-webkit-tap-highlight-color:transparent}:host{font-family:var(--c-font-family)}::-ms-reveal{display:none}:host{--_c-accordion-item-header-background-color:var(--c-accordion-item-header-background-color, var(--c-primary-200));--_c-accordion-item-outline-color:var(--c-accordion-item-outline-color, var(--c-primary-600));--_c-accordion-item-text-color:var(--c-accordion-item-text-color, var(--c-primary-600));max-width:100%}:host summary::-webkit-details-marker{display:none}.c-accordion-item{--_c-accordion-item-indicator-rotation:rotate(-90deg);--_c-accordion-item-content-height:0;--_c-accordion-item-min-height:46px;--_c-accordion-item-border-radius:6px;--_c-accordion-item-padding:12px;--_c-accordion-item-overflow:visible;--_c-accordion-item-outline-color-offset:2px;display:block;overflow:var(--_c-accordion-item-overflow)}.c-accordion-item--expanding{--_c-accordion-item-overflow:hidden !important;--_c-accordion-item-outline-color:transparent}.c-accordion-item--expanded{--_c-accordion-item-content-height:auto;--_c-accordion-item-indicator-rotation:rotate(90deg);--_c-accordion-item-overflow:visible}.c-accordion-item--outlined{box-shadow:inset 0 0 0 2px var(--_c-accordion-item-header-background-color);border-radius:var(--_c-accordion-item-border-radius)}.c-accordion-item__header{min-height:var(--_c-accordion-item-min-height);user-select:none;background-color:var(--_c-accordion-item-header-background-color);display:grid;column-gap:8px;align-items:center;padding:0 var(--_c-accordion-item-padding);border-radius:var(--_c-accordion-item-border-radius);cursor:pointer;grid-template-columns:1fr auto;border:none;text-align:left;margin:0;font-family:var(--c-font-family);position:relative}.c-accordion-item__header--has-icon{grid-template-columns:auto 1fr auto}.c-accordion-item__header--expanded{cursor:default}.c-accordion-item__header--expanded.c-accordion-item__header--collapsable{cursor:pointer}.c-accordion-item__header:focus{outline:2px var(--_c-accordion-item-outline-color) solid;outline-offset:var(--_c-accordion-item-outline-color-offset)}@supports selector(:focus-visible){.c-accordion-item__header:focus{outline:none}}.c-accordion-item__header:focus-visible{outline:2px var(--_c-accordion-item-outline-color) solid;outline-offset:var(--_c-accordion-item-outline-color-offset)}.c-accordion-item__title{margin-top:0;margin-bottom:0;font-weight:500;font-size:16px;line-height:1;color:var(--_c-accordion-item-text-color)}.c-accordion-item__content{padding:16px}.c-accordion-item__content-wrapper{overflow:visible}.c-accordion-item__icon{height:24px;font-size:24px;color:var(--_c-accordion-item-text-color);display:flex;align-items:center}.c-accordion-item__icon>*{height:24px;display:flex;align-items:center}.c-accordion-item__indicator{display:flex;align-items:center;color:var(--_c-accordion-item-text-color);justify-self:end}.c-accordion-item__indicator c-icon{width:24px;height:24px !important;transform:var(--_c-accordion-item-indicator-rotation);transition:transform 0.3s ease}";

const CAccordionItem = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.itemChange = index.createEvent(this, "itemChange", 7);
        this.collapsable = false;
        this.expanded = false;
        this.outlined = false;
        this._isCollapsing = false;
        this._isExpanding = false;
        this.hasCustomHeader = false;
        this.hasIcon = false;
    }
    handleKeyDown(event) {
        if (event.target.tagName === 'C-ACCORDION-ITEM' &&
            (event.key === 'Enter' || event.code === 'Space')) {
            event.preventDefault();
            this._onToggleAccordion(event);
        }
    }
    stop(event) {
        event.stopPropagation();
    }
    get _collapsedHeight() {
        const outlineHeight = this.outlined ? 4 : 0;
        return this._accordionHeader.offsetHeight + outlineHeight;
    }
    get _expandedHeight() {
        const outlineHeight = this.outlined ? 4 : 0;
        const headerHeight = this._accordionHeader.offsetHeight;
        const contentHeight = this._accordionContent.offsetHeight;
        return headerHeight + contentHeight + outlineHeight;
    }
    _onToggleAccordion(e) {
        e.preventDefault();
        if (!this.collapsable && this.expanded)
            return;
        this._accordionElement.classList.add('c-accordion-item--expanding');
        if (this._isCollapsing || !this.expanded) {
            this._expand();
        }
        else if (this._isExpanding || this.expanded) {
            this._collapse();
        }
    }
    _collapse() {
        this._isCollapsing = true;
        this.expanded = false;
        const startHeight = `${this._accordionElement.offsetHeight}px`;
        const endHeight = `${this._collapsedHeight}px`;
        if (this._animation) {
            this._animation.cancel();
        }
        this.itemChange.emit({ value: this.value, expanded: this.expanded });
        this._animation = this._accordionElement.animate({ height: [startHeight, endHeight] }, { duration: 300, easing: 'cubic-bezier(0.075, 0.82, 0.165, 1)' });
        this._animation.onfinish = () => this._onAnimationFinish(false);
        this._animation.oncancel = () => (this._isCollapsing = false);
    }
    _expand() {
        this._accordionElement.style.height = `${this._accordionElement.offsetHeight}px`;
        this.expanded = true;
        window.requestAnimationFrame(() => {
            this._isExpanding = true;
            const startHeight = `${this._collapsedHeight}px`;
            const endHeight = `${this._expandedHeight}px`;
            if (this._animation) {
                this._animation.cancel();
            }
            this.itemChange.emit({ value: this.value, expanded: this.expanded });
            this._animation = this._accordionElement.animate({ height: [startHeight, endHeight] }, { duration: 300, easing: 'cubic-bezier(0.25, 0.8, 0.5, 1)' });
            this._animation.onfinish = () => this._onAnimationFinish(true);
            this._animation.oncancel = () => (this._isExpanding = false);
        });
    }
    _onAnimationFinish(isOpen) {
        this.expanded = isOpen;
        this._animation = null;
        this._isCollapsing = false;
        this._isExpanding = false;
        this._accordionElement.style.height = '';
        this._accordionElement.classList.remove('c-accordion-item--expanding');
        this.expanded = isOpen;
    }
    componentWillLoad() {
        CAccordionItem._uniqueId += 1;
    }
    componentDidLoad() {
        this.hasCustomHeader = !!this.el.querySelector('[slot="header"]');
        this.hasIcon = !!this.el.querySelector('[slot="icon"]');
    }
    render() {
        const accordionClasses = {
            'c-accordion-item': true,
            'c-accordion-item--expanded': this.expanded,
            'c-accordion-item--outlined': this.outlined,
        };
        const headerClasses = {
            'c-accordion-item__header': true,
            'c-accordion-item__header--collapsable': this.collapsable,
            'c-accordion-item__header--expanded': this.expanded,
            'c-accordion-item__header--has-icon': this.hasIcon,
        };
        const indicatorClasses = {
            'c-accordion-item__indicator': true,
            'c-accordion-item__indicator--expanded': this.expanded,
        };
        return (index.h(index.Host, { key: '26341728a362c74a072504e606707f98a7e092fa' }, index.h("details", { key: '3d040ee2a3c74fbff1be32b7b92f983e1d435657', id: `panel__${CAccordionItem._uniqueId}`, ref: (el) => (this._accordionElement = el), class: accordionClasses, open: !!this.expanded }, index.h("summary", { key: '71bb0800c3d83d12b8464815aea21acdd082332c', ref: (el) => (this._accordionHeader = el), class: headerClasses, onClick: (event) => this._onToggleAccordion(event) }, this.hasIcon && (index.h("div", { key: '761ada6c0192e370955a16f9a458e5bfa4f90e8e', class: "c-accordion-item__icon", "aria-visible": "hidden" }, index.h("slot", { key: '4c395298939a1e78b0ccb0e7130c925a481e2f92', name: "icon" }))), this.hasCustomHeader && index.h("slot", { key: 'c80a9a3f65e0935d8d25b7ffe06d67b197812285', name: "header" }), !this.hasCustomHeader && (index.h("div", { key: '73f41f864c86593f67cff4bea186ad5c90ddd014', class: "c-accordion-item__title" }, this.heading)), index.h("div", { key: '17bc767bc7ddb798bb36b5ba83677bb47f2419df', class: indicatorClasses }, index.h("c-icon", { key: '8cfd62b574102b2506bceffe1e9ba190b0bf511c', path: mdi.mdiChevronRight, class: { expanded: this.expanded } }))), index.h("div", { key: '555d2e2d22b28fad4654edb6978bd679e9a28f93', ref: (el) => (this._accordionContent = el), class: "c-accordion-item__content-wrapper" }, index.h("div", { key: '27a70e2f85eeda310de3179c6caa2e79c8eaf292', class: "c-accordion-item__content", role: "region", "aria-labelledby": `header__${CAccordionItem._uniqueId}` }, index.h("slot", { key: 'e6c303c59281e90e1ed2c06454eafc6d14e4671d' }))))));
    }
    get el() { return index.getElement(this); }
};
CAccordionItem._uniqueId = 0;
CAccordionItem.style = cAccordionItemCss;

exports.c_accordion_item = CAccordionItem;
//# sourceMappingURL=c-accordion-item.entry.cjs.js.map

//# sourceMappingURL=c-accordion-item.cjs.entry.js.map