'use strict';

var index = require('./index-BTBT6v3v.js');
var mdi = require('./mdi-D4fs5l1W.js');

const cMenuCss = "html{box-sizing:border-box}body{margin:0}*,*:before,*:after{box-sizing:inherit;-webkit-tap-highlight-color:transparent}:host{font-family:var(--c-font-family)}::-ms-reveal{display:none}:host{--_c-menu-text-color:var(--c-menu-text-color, var(--c-text-system));--_c-menu-text-color-active:var(\n    --c-menu-text-color-active,\n    var(--c-primary-600)\n  );--_c-menu-background-color-hover:var(\n    --c-menu-background-color-hover,\n    var(--c-primary-200)\n  );--_c-menu-outline-color:var(--c-menu-outline-color, var(--c-primary-600));--_c-menu-header-height:38px;--_c-menu-padding:0 14px;border-radius:4px;display:block;font-size:14px;position:relative;user-select:none;height:fit-content}:host button{background:none;border-radius:4px;border:none;color:var(--_c-menu-text-color);cursor:pointer;display:block;font-family:var(--c-font-family);margin:0;padding:var(--_c-menu-padding);position:relative;user-select:none}:host button:focus{outline:2px var(--_c-menu-outline-color) solid;outline-offset:2px}@supports selector(:focus-visible){:host button:focus{outline:none}}:host button:focus-visible{outline:2px var(--_c-menu-outline-color) solid;outline-offset:2px}:host button:hover{background-color:var(--_c-menu-background-color-hover)}:host .c-menu__icon{line-height:20px;transition:transform 0.25s}:host .c-menu__icon--rotated{transform:rotate(180deg)}:host .c-menu__header{display:flex;flex:1 1 auto;margin-left:0;align-items:center;gap:8px;height:var(--_c-menu-header-height)}:host(.c-menu--custom){--_c-menu-padding:0;--_c-menu-background-color-hover:transparent !important;background:transparent !important}:host(.c-menu--small){--_c-menu-header-height:32px}:host(.c-menu--active) c-icon,:host(:hover) c-icon{color:var(--_c-menu-text-color-active)}:host(.c-menu--no-hover){--_c-menu-background-color-hover:transparent !important}.c-menu-overlay{position:fixed;inset:0;pointer-events:none}.c-menu-overlay__content{position:relative;height:100%;width:100%}";

const CMenu = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.items = [];
        this.contentClass = '';
        this.custom = false;
        this.small = false;
        this.flat = false;
        this.itemsPerPage = 6;
        this.menuItemsComponent = null;
        this.menuWrapperComponent = null;
        this.currentIndex = null;
        this.active = false;
    }
    handleKeyDown(ev) {
        const openKeys = ['ArrowDown', 'ArrowUp', 'Enter', ' '];
        if (!this.active && openKeys.includes(ev.key)) {
            ev.preventDefault();
            this.currentIndex = null;
            if (ev.key === 'ArrowDown') {
                this.currentIndex = 0;
            }
            if (ev.key === 'ArrowUp') {
                this.currentIndex = this.items.length - 1;
            }
            this._onClick();
        }
        if (ev.key === 'Escape') {
            this._hideMenu();
        }
    }
    _createWrapperElement() {
        const existingOverlay = document.querySelector('.c-menu-overlay__content');
        if (existingOverlay)
            return existingOverlay;
        const overlay = document.createElement('div');
        overlay.classList.add('c-menu-overlay');
        const overlayContent = document.createElement('div');
        overlayContent.classList.add('c-menu-overlay__content');
        overlay.appendChild(overlayContent);
        document.body.appendChild(overlay);
        return overlayContent;
    }
    _getNativeChild(parent = this.host) {
        let element = parent.shadowRoot.children[0];
        if (!!element.shadowRoot) {
            element = this._getNativeChild(element);
        }
        return element;
    }
    _addMenuItemsComponentListeners(height, width) {
        this.menuItemsComponent.onclose = () => {
            this._hideMenu();
            const element = this._getNativeChild();
            element.focus();
        };
        this.menuItemsComponent.addEventListener('open', (event) => this._onOpen(event, height, width), {
            once: true,
        });
    }
    _getHostPosition() {
        return this.host.getBoundingClientRect();
    }
    _hideMenu() {
        var _a;
        (_a = this.menuItemsComponent) === null || _a === void 0 ? void 0 : _a.remove();
        this.menuItemsComponent = null;
        this.active = false;
    }
    _onOpen(event, height, width) {
        window.requestAnimationFrame(() => {
            var _a, _b, _c;
            const { isInView, height: menuHeight, width: menuWidth } = event.detail;
            if (!isInView.y) {
                const posY = parseFloat(this.menuItemsComponent.style.top) - menuHeight - height;
                this.menuItemsComponent.style.top = `${posY}px`;
                this.menuItemsComponent.top = posY;
            }
            if (!isInView.x) {
                this.menuItemsComponent.style.left = `${parseFloat(this.menuItemsComponent.style.left) - menuWidth + width}px`;
            }
            this.active = true;
            this.menuItemsComponent.active = true;
            (_c = (_b = (_a = this.menuItemsComponent) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelector('ul')) === null || _c === void 0 ? void 0 : _c.focus();
        });
    }
    _onClick() {
        if (this.menuItemsComponent)
            return;
        const { bottom, left, width, height } = this._getHostPosition();
        this.menuItemsComponent = document.createElement('c-menu-items');
        this.menuItemsComponent.style.top = `${bottom}px`;
        this.menuItemsComponent.style.left = `${left}px`;
        this.menuItemsComponent.style.minWidth = `${width}px`;
        this.menuItemsComponent.parent = this.host;
        this.menuItemsComponent.items = this.items;
        this.menuItemsComponent.small = this.small;
        this.menuItemsComponent.itemsPerPage = this.itemsPerPage;
        this.menuItemsComponent.top = bottom;
        this.menuItemsComponent.id = `c-menu-items-${CMenu._uniqueId}`;
        this.menuItemsComponent.index = this.currentIndex;
        this.menuItemsComponent.setAttribute('tabindex', '-1');
        this.menuItemsComponent.setAttribute('role', 'listbox');
        if (this.contentClass) {
            this.menuItemsComponent.classList.add(this.contentClass);
        }
        this._addMenuItemsComponentListeners(height, width);
        this._createWrapperElement().appendChild(this.menuItemsComponent);
        window.setTimeout(() => {
            var _a, _b, _c, _d;
            (_d = (_c = (_b = (_a = this.menuItemsComponent) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.children[0]) === null || _c === void 0 ? void 0 : _c.children[0]) === null || _d === void 0 ? void 0 : _d.focus();
        }, 200);
    }
    componentWillLoad() {
        CMenu._uniqueId += 1;
    }
    disconnectedCallback() {
        this._hideMenu();
    }
    render() {
        const hostClasses = {
            'c-menu': true,
            'c-menu--custom': this.custom,
            'c-menu--active': this.active,
            'c-menu--no-hover': this.flat,
            'c-menu--small': this.small,
        };
        return (index.h(index.Host, { key: 'd51d61bddf17421f1a027af1bb7fdd821e48ff3e', class: hostClasses }, index.h("button", { key: 'd0b0f6599f2c31cf02f980fd2ce726c3927f1b80', "aria-expanded": this.active.toString(), "aria-haspopup": "listbox", "aria-controls": `c-menu-items-${CMenu._uniqueId}`, class: {
                'c-menu-wrapper': !this.custom,
                custom: this.custom,
            }, tabindex: "0", type: "button", onClick: () => this._onClick() }, this.custom ? (index.h("slot", null)) : (index.h("div", { class: "c-menu__header" }, index.h("slot", null), index.h("c-icon", { path: mdi.mdiChevronDown, class: this.active
                ? 'c-menu__icon c-menu__icon--rotated'
                : 'c-menu__icon' }))))));
    }
    get host() { return index.getElement(this); }
};
CMenu._uniqueId = 0;
CMenu.style = cMenuCss;

const getScrollParent = (element) => {
    return new Promise((resolve) => {
        if (!element) {
            resolve(undefined);
        }
        let parent = element.parentNode;
        while (parent) {
            if (parent.shadowRoot === undefined) {
                parent = parent.host;
            }
            else {
                const { overflow, overflowX } = window.getComputedStyle(parent);
                if (overflowX !== 'scroll' &&
                    overflow.split(' ').every((o) => o === 'auto' || o === 'scroll')) {
                    resolve(parent);
                }
                parent = parent.parentNode;
            }
        }
        resolve(document.documentElement);
    });
};

const cMenuItemsCss = "html{box-sizing:border-box}body{margin:0}*,*:before,*:after{box-sizing:inherit;-webkit-tap-highlight-color:transparent}:host{font-family:var(--c-font-family)}::-ms-reveal{display:none}:host,:root{--_c-menu-items-background-color-hover:var(--c-menu-items-background-color-hover, var(--c-primary-200));--_c-menu-items-text-color:var(--c-menu-items-text-color, var(--c-text-body));--_c-menu-items-text-color-active:var(--c-menu-items-text-color-active, var(--c-primary-600));position:absolute;border-radius:inherit;display:flex;pointer-events:none;inset:inherit}ul.c-menu-items{--_c-menu-item-font-size:14px;margin:0;padding:0;background-color:var(--c-white);list-style:none;animation:0.1s 1 fade-in cubic-bezier(0.25, 0.8, 0.5, 1);box-shadow:2px 4px 10px rgba(0, 0, 0, 0.1607843137);width:100%;overflow-y:scroll;pointer-events:auto;border-radius:4px;visibility:hidden}ul.c-menu-items--small{--_c-menu-item-font-size:12px}ul.c-menu-items--active{visibility:visible}li{align-items:center;background:var(--c-white);column-gap:12px;cursor:pointer;display:flex;flex-wrap:nowrap;font-size:var(--_c-menu-item-font-size);height:var(--_c-menu-item-height);padding-left:10px;padding-right:10px;outline:none;white-space:nowrap;pointer-events:auto}li:not(.disabled):hover,li.active{background:var(--_c-menu-items-background-color-hover);color:var(--_c-menu-items-text-color-active)}li.icon-start{flex-direction:row-reverse;justify-content:flex-end}li.icon-end{justify-content:space-between}li.disabled{cursor:default;color:var(--c-tertiary-400)}@keyframes fade-in{from{opacity:0;transform:translateY(-8px)}to{opacity:1;transform:translateY(0)}}";

const CMenuItems = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.close = index.createEvent(this, "close", 7);
        this.open = index.createEvent(this, "open", 7);
        this.items = [];
        this.small = false;
        this.active = false;
        this.parentType = 'menu';
        this.top = 0;
        this.index = null;
        this.itemsPerPage = 6;
        this.isInView = true;
        this.currentIndex = null;
        this._parentTop = 0;
        this._itemHeight = 42;
        this._itemHeightSmall = 36;
        this._renderItem = (item) => {
            const classes = {
                disabled: item.disabled,
                'icon-start': item.iconPosition === 'start',
                'icon-end': item.iconPosition === 'end',
            };
            const onItemClick = (event, item) => {
                event.stopPropagation();
                if (!item.disabled) {
                    item.action();
                    this.close.emit();
                }
            };
            return (index.h("li", { "aria-disabled": (!!item.disabled).toString(), class: classes, tabindex: "-1", role: "menuitem", onClick: (event) => onItemClick(event, item) }, item.name, item.icon && (index.h("svg", { class: "icon", width: "20", height: "20", viewBox: "0 0 24 24" }, index.h("path", { d: item.icon })))));
        };
    }
    onIndexChange(index) {
        this.listItems.forEach((item, i) => {
            item.classList.toggle('active', i === index);
            if (i === index) {
                item.focus();
            }
        });
    }
    handleKeyDown(event) {
        if (event.key === 'ArrowDown') {
            event.preventDefault();
            if (this.currentIndex === null) {
                this.currentIndex = 0;
            }
            else if (this.currentIndex + 1 < this.items.length) {
                this.currentIndex += 1;
            }
        }
        if (event.key === 'ArrowUp') {
            event.preventDefault();
            if (this.currentIndex === null) {
                this.currentIndex = this.items.length - 1;
            }
            else if (this.currentIndex > 0) {
                this.currentIndex -= 1;
            }
        }
        if (event.key === 'Escape') {
            this.close.emit();
            this.currentIndex = null;
        }
        if (event.key === 'Enter') {
            event.preventDefault();
            if (this.currentIndex !== null) {
                const item = this.items[this.currentIndex];
                if (!item.disabled) {
                    item.action();
                    this.close.emit();
                }
                return;
            }
            this.currentIndex = 0;
        }
        if (event.key === ' ') {
            event.preventDefault();
            if (this.currentIndex !== null) {
                const item = this.items[this.currentIndex];
                if (item === null || item === void 0 ? void 0 : item.disabled)
                    return;
                item === null || item === void 0 ? void 0 : item.action();
            }
            this.close.emit();
        }
        if (event.key === 'Tab') {
            if (this.parentType !== 'menu' && this.currentIndex !== null) {
                const item = this.items[this.currentIndex];
                if (!(item === null || item === void 0 ? void 0 : item.disabled)) {
                    item === null || item === void 0 ? void 0 : item.action();
                }
            }
            this.close.emit();
        }
        if (event.key === 'PageUp') {
            this.currentIndex = Math.max(0, this.currentIndex - this.itemsPerPage);
        }
        if (event.key === 'PageDown') {
            this.currentIndex = Math.min(this.items.length - 1, this.currentIndex + this.itemsPerPage);
        }
    }
    get listItems() {
        var _a, _b;
        return Array.from(((_b = (_a = this.host) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelectorAll('li')) || []);
    }
    _handleItemsPerPage() {
        const itemHeight = this.small ? this._itemHeightSmall : this._itemHeight;
        const containerHeight = this.itemsPerPage * itemHeight + itemHeight / 2;
        this._listElement.style.maxHeight = `${containerHeight}px`;
        this._listElement.style.setProperty('--_c-menu-item-height', `${itemHeight}px`);
    }
    _onOpen() {
        this._handleItemsPerPage();
        window.requestAnimationFrame(async () => {
            const viewportHeight = window.innerHeight;
            const viewportWidth = window.innerWidth;
            const { bottom, right, height, width } = this._listElement.getBoundingClientRect();
            const { top: parentTop } = this.parent.getBoundingClientRect();
            this._parentTop = parentTop;
            this.scrollingParent = await getScrollParent(this.parent);
            this._boundFn = this._onScroll.bind(this);
            this.scrollingParent.addEventListener('scroll', this._boundFn);
            this.open.emit({
                height,
                isInView: {
                    x: right < viewportWidth,
                    y: bottom < viewportHeight,
                },
                width,
            });
        });
    }
    _onScroll() {
        const { top: parentTop } = this.parent.getBoundingClientRect();
        const differenceY = this._parentTop - parentTop;
        this.host.style.top = `${this.top - differenceY}px`;
    }
    _handleClick(event) {
        if (!event.composedPath().includes(this.host)) {
            this.close.emit();
        }
    }
    _handleZIndex() {
        const styles = window.getComputedStyle((this.parent.assignedSlot || this.parent).parentElement);
        const zIndex = styles.getPropertyValue('z-index');
        this.host.style.zIndex = zIndex === 'auto' ? '1' : zIndex;
    }
    componentDidLoad() {
        this._boundClickFn = this._handleClick.bind(this);
        window.addEventListener('click', this._boundClickFn, {
            once: true,
        });
        this._handleZIndex();
        this._onOpen();
        this.currentIndex = this.index;
    }
    disconnectedCallback() {
        this.scrollingParent.removeEventListener('scroll', this._boundFn);
        window.removeEventListener('click', this._boundClickFn);
    }
    render() {
        const listClasses = {
            'c-menu-items': true,
            'c-menu-items--small': this.small,
            'c-menu-items--active': this.active,
        };
        return (index.h(index.Host, { key: '577087100c22f5eb4c35b360c05893653248a76a' }, index.h("ul", { key: 'e2279cffb96e91a05f71066c041f9446161e8ba4', class: listClasses, ref: (el) => (this._listElement = el) }, this.items.map((item) => this._renderItem(item)))));
    }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "currentIndex": ["onIndexChange"]
    }; }
};
CMenuItems.style = cMenuItemsCss;

exports.c_menu = CMenu;
exports.c_menu_items = CMenuItems;
//# sourceMappingURL=c-menu.c-menu-items.entry.cjs.js.map

//# sourceMappingURL=c-menu_2.cjs.entry.js.map