'use strict';

var index = require('./index-BTBT6v3v.js');

const cStepsCss = "html{box-sizing:border-box}body{margin:0}*,*:before,*:after{box-sizing:inherit;-webkit-tap-highlight-color:transparent}:host{font-family:var(--c-font-family)}::-ms-reveal{display:none}:host{--_c-steps-outline-color:var(--c-steps-outline-color, var(--c-primary-600));--_c-steps-color:var(--c-step-color, var(--c-tertiary-500));--_c-steps-color-complete:var(--c-step-color-complete, var(--c-primary-600));width:100%;display:grid;gap:8px;border-radius:6px}@supports selector(:focus-visible){:host(:focus){outline:none}}:host(:focus-visible){outline:2px var(--_c-steps-outline-color) solid;outline-offset:2px}.c-steps{--c-steps-divider-width:calc(100% + 160px);--c-steps-divider-margin:10px -80px 0;width:100%;display:flex;flex-wrap:nowrap}.c-steps slot{display:flex;justify-items:space-between;width:100%}.c-steps ::slotted(.divider){height:2px;flex:1;background-color:var(--_c-steps-color);width:var(--c-steps-divider-width);margin:var(--c-steps-divider-margin) !important}.c-steps ::slotted(.divider.complete){background-color:var(--_c-steps-color-complete);height:4px;margin-top:9px}.c-steps.mobile{--c-steps-divider-width:calc(100% + 11px);--c-steps-divider-margin:10px -10px 0}.visuallyhidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;white-space:nowrap;width:1px}";

const CSteps = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.changeValue = index.createEvent(this, "changeValue", 3);
        this.isMobile = false;
        this.label = '';
        this._isInitialized = false;
    }
    watchPropHandler() {
        this._handleDividers();
    }
    _handleDividers() {
        this._stepElements = this.host.querySelectorAll('c-step');
        const dividers = this.host.querySelectorAll('.divider');
        this._stepElements.forEach((item, index) => {
            item.current = index + 1 === +this.value;
            item.complete = index + 1 < +this.value;
            if (index + 1 < this._stepElements.length) {
                const div = this._isInitialized
                    ? dividers[index]
                    : document.createElement('div');
                div.classList.toggle('complete', !!item.complete);
                if (!this._isInitialized) {
                    div.classList.add('divider');
                    item.after(div);
                }
            }
            if (item.current) {
                this.label = item.textContent;
            }
        });
        this._isInitialized = true;
    }
    componentDidLoad() {
        this._handleDividers();
        this._resizeObserver = new ResizeObserver(([entry]) => {
            const maxWidth = this._stepElements.length * 180;
            this.isMobile = maxWidth > entry.contentRect.width;
            this.host.shadowRoot
                .querySelector('.c-steps')
                .classList.toggle('mobile', this.isMobile);
            this._stepElements.forEach((node) => {
                node.classList.toggle('mobile', this.isMobile);
            });
        });
        window.requestAnimationFrame(() => {
            this._resizeObserver.observe(this.host);
        });
    }
    _getA11yMessage(total, current) {
        return `
      Steps, step ${Math.min(current, total)} of ${total}.
      ${this.label}.
      ${current - 1} step${current - 1 !== 1 ? 's' : ''} marked as completed.
    `;
    }
    render() {
        return (index.h(index.Host, { key: '2b88cee8bdd6d69c81a667a1e4d008ea33e09b94', tabindex: "0" }, this._stepElements && (index.h("span", { key: 'bd512f57cf6ab6fec27b8a5a3bd1a8a5ff825700', class: "visuallyhidden" }, this._getA11yMessage(this._stepElements.length, +this.value))), index.h("div", { key: '6a4847a5f6fa86f01aa1143504b278a9f23f9509', class: "c-steps", "aria-hidden": "true" }, index.h("slot", { key: '1fdde35e7f63acde28a3b4aefdeddeba7629d143' })), this.isMobile && (index.h("div", { key: '55279c07864316d5c75fdbc96ae69ee69bdee415', class: "c-steps__label", "aria-hidden": "true" }, this.label))));
    }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "value": ["watchPropHandler"]
    }; }
};
CSteps.style = cStepsCss;

exports.c_steps = CSteps;
//# sourceMappingURL=c-steps.entry.cjs.js.map

//# sourceMappingURL=c-steps.cjs.entry.js.map