import { h, Host, } from "@stencil/core";
export class CButton {
    constructor() {
        this.inverted = false;
        this.outlined = false;
        this.ghost = false;
        this.danger = false;
        this.grouped = false;
        this.text = false;
        this.loading = false;
        this.fit = false;
        this.noRadius = false;
        this.type = 'button';
        this.disabled = false;
        this.size = 'default';
        this.target = '_blank';
        this.tabs = false;
        this._onClick = (event, center = false) => {
            var _a;
            if (this.disabled) {
                event.preventDefault();
                return;
            }
            this._rippleElement.createRipple(event, this._container, center);
            if (this.tabs) {
                this.tabChange.emit({
                    value: (_a = this.value) !== null && _a !== void 0 ? _a : this.hostElement.dataset.index,
                    element: this.hostElement,
                });
            }
            if (this.type === 'submit') {
                const submitButton = this._createHiddenSubmitButton();
                submitButton.click();
                submitButton.remove();
            }
        };
        this._createHiddenSubmitButton = () => {
            const form = this._closestElementComposed('form', this._container);
            const submitButton = document.createElement('button');
            submitButton.type = this.type;
            submitButton.style.display = 'none';
            submitButton.disabled = this.disabled;
            form.appendChild(submitButton);
            return submitButton;
        };
        this._onKeyDown = (event) => {
            if (['Space', 'Enter'].includes(event.code)) {
                if (!!this.href) {
                    window.open(this.href, this.target);
                }
                event.preventDefault();
                this._onClick(event, true);
            }
        };
    }
    onTabFocus() {
        var _a;
        this.tabFocus.emit((_a = this.value) !== null && _a !== void 0 ? _a : this.hostElement.dataset.index);
    }
    _closestElementComposed(selector, base) {
        function __closestFrom(el) {
            const found = el.closest(selector);
            return found ? found : __closestFrom(el.getRootNode().host);
        }
        return __closestFrom(base);
    }
    componentWillLoad() {
        this._containerhasDescriptionSlot = !!this.hostElement.querySelector('[slot="description"]');
    }
    render() {
        const contentClasses = {
            'c-button__content': true,
            'c-button__content--description': this._containerhasDescriptionSlot,
            'c-button__content--fitted': !!this.fit,
            'c-button__content--large': this.size === 'large',
            'c-button__content--no-radius': !!this.noRadius,
            'c-button__content--small': this.size === 'small',
        };
        const innerClasses = {
            'c-button__content__inner': true,
            'hide-text': this.loading,
        };
        const buttonClasses = {
            fit: !!this.fit,
            grouped: this.grouped,
            outlined: this.outlined,
        };
        const hostClasses = {
            'c-button': true,
            'c-button--ghost': this.ghost,
            'c-button--outlined': this.outlined,
            'c-button--danger': this.danger,
            'c-button--disabled': this.disabled,
            'c-button--inverted': this.inverted,
            'c-button--text': this.text,
            'c-button--fitted': !!this.fit,
            'c-button--description': !!this._containerhasDescriptionSlot,
            'c-button--active': this.grouped && !this.outlined,
            'c-button--no-radius': !!this.noRadius,
            [`c-button--${this.size}`]: true,
        };
        const descriptionSlotClasses = {
            'c-button__content__description': this._containerhasDescriptionSlot,
            'c-button__content__description--loading': this.loading,
        };
        const Tag = !!this.href ? 'a' : 'button';
        const hostAttributes = {
            onKeyDown: this._onKeyDown,
        };
        const attributes = {
            id: this.hostId,
            class: buttonClasses,
            disabled: this.disabled,
            onClick: this._onClick,
            type: this.type,
        };
        let linkAttributes = {};
        if (!!this.href) {
            linkAttributes = { href: this.href, target: this.target };
        }
        const spinnerSizes = {
            small: 20,
            default: 24,
            large: 28,
        };
        return (h(Host, Object.assign({ key: '1e7fd3d5ed864159709a2e34ec23fa62830e84b8', class: hostClasses }, hostAttributes), h(Tag, Object.assign({ key: '372d34c304df775577e9165ae24b88f299a38d2c' }, attributes, linkAttributes), h("div", { key: '3ab7cc2472bda14f499a520c4dd53a0543ead5ba', class: contentClasses, ref: (el) => (this._container = el) }, h("div", { key: '929fbd77601b9f58d7d0002e4213a50ae495dfd0', class: innerClasses }, this.loading && (h("div", { key: '90e97a37732c2903b718c11439232f563294eb7d', class: "c-button__loader" }, h("c-spinner", { key: '277ee152de7e3c61891c52ee51f771f85df0a5ed', color: "var(--_c-button-loader-color)", size: spinnerSizes[this.size] }))), h("slot", { key: '7b6a4797d7bd515f8171b8d83a3c3a5b30c3be81' })), this._containerhasDescriptionSlot && (h("div", { key: '479ed7791480a8ac29864b53cad7db65826eba3f', class: descriptionSlotClasses }, h("slot", { key: '634af8d8b67366d3e28f9eefd961c5cc68d1b34c', name: "description" })))), h("c-ripple", { key: '670f5e91b610d7e7d19684a725cfec20d0537eec', ref: (el) => (this._rippleElement = el) }))));
    }
    static get is() { return "c-button"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-button.css"]
        };
    }
    static get properties() {
        return {
            "inverted": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Inverted button style for dark backgrounds"
                },
                "getter": false,
                "setter": false,
                "attribute": "inverted",
                "reflect": false,
                "defaultValue": "false"
            },
            "outlined": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Outlined button style"
                },
                "getter": false,
                "setter": false,
                "attribute": "outlined",
                "reflect": false,
                "defaultValue": "false"
            },
            "ghost": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Light button background"
                },
                "getter": false,
                "setter": false,
                "attribute": "ghost",
                "reflect": false,
                "defaultValue": "false"
            },
            "danger": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Danger variant style"
                },
                "getter": false,
                "setter": false,
                "attribute": "danger",
                "reflect": false,
                "defaultValue": "false"
            },
            "grouped": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "True when used as a tab button"
                },
                "getter": false,
                "setter": false,
                "attribute": "grouped",
                "reflect": false,
                "defaultValue": "false"
            },
            "text": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Transparent button background"
                },
                "getter": false,
                "setter": false,
                "attribute": "text",
                "reflect": false,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Display loader on the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "loading",
                "reflect": false,
                "defaultValue": "false"
            },
            "fit": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Fit width to containing element"
                },
                "getter": false,
                "setter": false,
                "attribute": "fit",
                "reflect": false,
                "defaultValue": "false"
            },
            "noRadius": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Remove the default border radius"
                },
                "getter": false,
                "setter": false,
                "attribute": "no-radius",
                "reflect": false,
                "defaultValue": "false"
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'button' | 'submit'",
                    "resolved": "\"button\" | \"submit\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Button type"
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false,
                "defaultValue": "'button'"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": true,
                "defaultValue": "false"
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Value for the button\n- for use in the c-tab-buttons"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "size": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'default' | 'small' | 'large'",
                    "resolved": "\"default\" | \"large\" | \"small\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Size of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "size",
                "reflect": false,
                "defaultValue": "'default'"
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hyperlink url"
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hyperlink target"
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false,
                "defaultValue": "'_blank'"
            },
            "tabs": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Used a s atab button"
                },
                "getter": false,
                "setter": false,
                "attribute": "tabs",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "tabChange",
                "name": "tabChange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit changes to the parent"
                },
                "complexType": {
                    "original": "{\n    value: number | string;\n    element: HTMLCButtonElement;\n  }",
                    "resolved": "{ value: string | number; element: HTMLCButtonElement; }",
                    "references": {
                        "HTMLCButtonElement": {
                            "location": "global",
                            "id": "global::HTMLCButtonElement"
                        }
                    }
                }
            }, {
                "method": "tabFocus",
                "name": "tabFocus",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit focus to the parent"
                },
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
    static get listeners() {
        return [{
                "name": "focus",
                "method": "onTabFocus",
                "target": undefined,
                "capture": false,
                "passive": true
            }];
    }
}
//# sourceMappingURL=c-button.js.map
