import { Host, h, } from "@stencil/core";
export class CCheckbox {
    constructor() {
        this.checked = false;
        this.disabled = false;
        this.hideDetails = false;
        this.hint = '';
        this.indeterminate = false;
        this.label = '';
        this.required = false;
        this.valid = true;
        this.validation = 'Required field';
        this.value = false;
        this.trueValue = true;
        this.falseValue = false;
    }
    get _id() {
        return this.hostId || `checkbox_${CCheckbox._uniqueId}`;
    }
    onValueChange(value) {
        this.checked = this.trueValue === value;
        this.internals.setFormValue(this.checked ? this.trueValue.toString() : this.falseValue.toString());
    }
    componentWillLoad() {
        CCheckbox._uniqueId += 1;
        this.checked = this.checked || this.value === this.trueValue;
        this.internals.setFormValue(this.checked ? this.trueValue.toString() : this.falseValue.toString());
    }
    _toggleState(event) {
        if (this.disabled)
            return;
        this._rippleElement.createRipple(event, this._container, true);
        this.checked = !this.checked;
        this.changeValue.emit(this.checked ? this.trueValue : this.falseValue);
        this.internals.setFormValue(this.checked ? this.trueValue.toString() : this.falseValue.toString());
    }
    render() {
        const wrapperClasses = {
            'c-checkbox': true,
            'c-checkbox--disabled': this.disabled,
            'c-checkbox--error': !this.valid,
        };
        const labelClasses = {
            'c-checkbox__label': true,
            'c-checkbox__label--indeterminate': this.indeterminate,
        };
        const slotHasContent = !!this.el.childNodes.length;
        return (h(Host, { key: 'e39e3e681c8b1267e58182872f704cb048e14daa' }, h("div", { key: '83a582b3231bfafc6f3deabe3b5cad87c1dac99c', class: wrapperClasses }, h("input", Object.assign({ key: '9b20de6459795c6b8f41d1aa31212fa8dc071bf6', class: "visuallyhidden", id: "checkbox" }, (!!this.hostName ? { name: this.hostName } : {}), { type: "checkbox", "aria-checked": this.checked.toString(), "aria-disabled": this.disabled.toString(), checked: this.checked ? true : undefined, disabled: this.disabled, onChange: (event) => this._toggleState(event) })), h("label", { key: 'ef2eb908f56cab3de39a53270a95cea892db99ec', class: labelClasses, htmlFor: "checkbox" }, h("div", { key: 'f260766abb707826ac5498301a2966d6f714c66f', class: "ripple", ref: (el) => (this._container = el) }, h("svg", { key: '8d43f917054de11772dd246871947a2291086d4a', viewBox: "0 0 100 100" }, !this.indeterminate && this.checked && (h("path", { key: '448595e010c4292f113b58837f6dca92522b6acd', class: "path", d: "M 12 52 l 24 24 l 47 -47 l -3 -3 l -44 44 l -21 -21 l -3 3" })), this.indeterminate && (h("path", { key: 'd88bb390971e37d265a2ac5676cf890ebca09729', class: "path", d: "M20 56 h60 v-8 h-60 z" }))), h("c-ripple", { key: '67101de46a7627092f9280756fe8b310a95e2635', ref: (el) => (this._rippleElement = el) })), (!!this.label || slotHasContent) && (h("div", { key: '186fa5f1b2aeb8750a72e4be36c8182b1fe8b903', class: "c-checkbox__label-content" }, !!this.label ? this.label : h("slot", null), this.required && h("span", { key: '6b9f54993ec9bcc98780bf36401ce6aaf887e78e', class: "required" }, "\u00A0*"))))), !this.hideDetails && (h("c-message", { key: '1a73cca7a518fcd65370f67b09ba6ae257e0eb15', hint: this.hint, inputId: this._id, valid: this.valid, validation: this.validation }))));
    }
    static get is() { return "c-checkbox"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["c-checkbox.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-checkbox.css"]
        };
    }
    static get properties() {
        return {
            "checked": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the checkbox is selected."
                },
                "getter": false,
                "setter": false,
                "attribute": "checked",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the checkbox"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "hideDetails": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hide the hint and error messages"
                },
                "getter": false,
                "setter": false,
                "attribute": "hide-details",
                "reflect": false,
                "defaultValue": "false"
            },
            "hint": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hint text for the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "hint",
                "reflect": false,
                "defaultValue": "''"
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the element"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "indeterminate": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Indeterminate state"
                },
                "getter": false,
                "setter": false,
                "attribute": "indeterminate",
                "reflect": false,
                "defaultValue": "false"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Element label"
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false,
                "defaultValue": "''"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set as required"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            },
            "valid": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the validity of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "valid",
                "reflect": false,
                "defaultValue": "true"
            },
            "validation": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Custom validation message"
                },
                "getter": false,
                "setter": false,
                "attribute": "validation",
                "reflect": false,
                "defaultValue": "'Required field'"
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "string | boolean",
                    "resolved": "boolean | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The input value\n- Only used when the checkbox participates in a native `<form>`"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false,
                "defaultValue": "false"
            },
            "trueValue": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "boolean | string",
                    "resolved": "boolean | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The value when the checkbox is checked"
                },
                "getter": false,
                "setter": false,
                "attribute": "true-value",
                "reflect": false,
                "defaultValue": "true"
            },
            "falseValue": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "boolean | string",
                    "resolved": "boolean | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The value when the checkbox is unchecked"
                },
                "getter": false,
                "setter": false,
                "attribute": "false-value",
                "reflect": false,
                "defaultValue": "false"
            },
            "hostName": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "name"
                        }],
                    "text": "Name of the input\n- Only used when the checkbox participates in a native `<form>`"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Triggered when element is checked or unchecked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "onValueChange"
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
CCheckbox._uniqueId = 0;
//# sourceMappingURL=c-checkbox.js.map
