import { h, Host } from "@stencil/core";
export class CIconButton {
    constructor() {
        this.danger = false;
        this.loading = false;
        this.text = false;
        this.inverted = false;
        this.outlined = false;
        this.path = null;
        this.ghost = false;
        this.disabled = false;
        this.size = 'default';
        this._onClick = (event) => {
            this._rippleElement.createRipple(event, this._container);
        };
    }
    _renderBadge() {
        return h("c-badge", null, this.badge);
    }
    _hostClasses() {
        return {
            'c-icon-button': true,
            'c-icon-button--disabled': !!this.disabled,
            'c-icon-button--danger': !!this.danger,
            'c-icon-button--text': !!this.text,
            'c-icon-button--ghost': !!this.ghost,
            'c-icon-button--outlined': !!this.outlined,
            'c-icon-button--inverted': !!this.inverted,
            'c-icon-button--small': this.size === 'small',
            'c-icon-button--x-small': this.size === 'x-small',
        };
    }
    render() {
        const spinnerSizes = {
            'x-small': 18,
            small: 20,
            default: 24,
        };
        return (h(Host, { key: '7b9493a65af9c011287174ff9046eaf365d681eb', class: this._hostClasses() }, h("button", { key: 'bdb638941030862d65a715a97d0a9fa06bee1ca2', disabled: this.disabled, onClick: this._onClick }, h("div", { key: '07335d16aa5b535d65fefd8f6f411442cb24bc6e', class: "inner-container", ref: (el) => (this._container = el) }, this.loading && (h("c-spinner", { key: 'd9506ba5286d4acd1e7ff37797aef85ab93627b2', color: "var(--_c-icon-button-loader-color)", size: spinnerSizes[this.size] })), !this.loading && (h("slot", { key: '851b1bbc5424ec8c49491e63a1e3c34a6d40722f' }, this.path && (h("svg", { key: 'd7d20b55bd3bf581a827f482725f14081233f0a8', width: "24", height: "24", viewBox: "0 0 24 24" }, h("path", { key: '67ee591b7d91d79083360013b22ffcdce4357a9f', d: this.path })))))), this.badge && this._renderBadge(), h("c-ripple", { key: 'b2a8f77326ac01b2b5c99d66b73832ecd84171e3', ref: (el) => (this._rippleElement = el) }))));
    }
    static get is() { return "c-icon-button"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-icon-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-icon-button.css"]
        };
    }
    static get properties() {
        return {
            "badge": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Show a badge on top of the icon"
                },
                "getter": false,
                "setter": false,
                "attribute": "badge",
                "reflect": false
            },
            "danger": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Danger variant of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "danger",
                "reflect": false,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Loading variant of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "loading",
                "reflect": false,
                "defaultValue": "false"
            },
            "text": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Text variant of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "text",
                "reflect": false,
                "defaultValue": "false"
            },
            "inverted": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Inverted color for dark backgrounds"
                },
                "getter": false,
                "setter": false,
                "attribute": "inverted",
                "reflect": false,
                "defaultValue": "false"
            },
            "outlined": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Outlined variant of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "outlined",
                "reflect": false,
                "defaultValue": "false"
            },
            "path": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Path for the svg icon"
                },
                "getter": false,
                "setter": false,
                "attribute": "path",
                "reflect": false,
                "defaultValue": "null"
            },
            "ghost": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Ghost variant of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "ghost",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "size": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'default' | 'x-small' | 'small'",
                    "resolved": "\"default\" | \"small\" | \"x-small\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Size of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "size",
                "reflect": false,
                "defaultValue": "'default'"
            }
        };
    }
}
//# sourceMappingURL=c-icon-button.js.map
