import { Host, h, } from "@stencil/core";
export class CInput {
    constructor() {
        this.active = false;
        this.automaticFocus = false;
        this.disabled = false;
        this.hideDetails = false;
        this.hint = '';
        this.itemsPerPage = 6;
        this.labelOnTop = false;
        this.max = null;
        this.min = null;
        this.readonly = false;
        this.required = false;
        this.rows = 1;
        this.shadow = false;
        this.step = null;
        this.valid = true;
        this.validate = false;
        this.validateOnBlur = false;
        this.validation = 'Required field';
        this.variant = 'text';
        this.isFocused = false;
        this.labelWidth = 0;
        this.preSlotWidth = 0;
        this.statusText = '';
        this.currentIndex = null;
        this._hasBlurred = false;
        this._debounce = null;
        this._observer = new IntersectionObserver((entries, observer) => {
            entries.forEach((entry) => {
                if (entry.isIntersecting) {
                    this._calculateElementWidths();
                    observer.unobserve(entry.target);
                }
            });
        }, { threshold: 1 });
        this._onBlur = () => {
            setTimeout(() => {
                this.isFocused = false;
                this._hasBlurred = true;
                this._onReset();
            }, 200);
        };
        this._onFocus = (click = true) => {
            var _a, _b;
            if (this.disabled)
                return;
            this.isFocused = true;
            (_a = this.inputField) === null || _a === void 0 ? void 0 : _a.focus();
            if (click) {
                (_b = this.inputField) === null || _b === void 0 ? void 0 : _b.click();
                if (this.variant === 'select') {
                    this.itemClick.emit();
                }
            }
            if (this.inputField && !this.labelOnTop) {
                this.inputField.placeholder =
                    !!this.value || !this.placeholder ? '' : this.placeholder;
            }
        };
    }
    onValidChange() {
        if (this.validateOnBlur && !this._hasBlurred)
            return;
        this._setAriaDescriptionId();
    }
    onValidationMessageChange() {
        this._updateStatusText();
    }
    onValueChange(value) {
        if (!value) {
            this._onReset();
        }
    }
    onPlaceholderChange(placeholder) {
        if (placeholder)
            this._onReset();
    }
    async reset() {
        this._onReset();
    }
    componentDidLoad() {
        var _a, _b, _c, _d;
        if (this.automaticFocus) {
            setTimeout(() => {
                this._onFocus(false);
            }, 500);
        }
        this._calculateElementWidths();
        this._setAriaDescriptionId();
        if (this.label) {
            this._observer.observe(this._labelRef);
        }
        (_a = this.inputField) === null || _a === void 0 ? void 0 : _a.addEventListener('focus', () => this._onFocus(false));
        (_b = this.inputField) === null || _b === void 0 ? void 0 : _b.addEventListener('blur', () => this._onBlur());
        (_c = this.inputField) === null || _c === void 0 ? void 0 : _c.addEventListener('keypress', this._preventNonNumericalInput);
        if (this.inputField && !this.labelOnTop) {
            this.inputField.placeholder =
                !!this.label || !this.placeholder ? '' : this.placeholder;
            this.inputField.title = (_d = this.label) !== null && _d !== void 0 ? _d : this.placeholder;
            requestAnimationFrame(() => {
                const container = this.inputField.closest('.c-input-menu__input');
                if (!container)
                    return;
                container.dataset.placeholder = this.placeholder;
            });
        }
        if (this.labelOnTop && this.placeholder && this.inputField) {
            this.inputField.placeholder = this.placeholder;
        }
    }
    disconnectedCallback() {
        var _a, _b, _c, _d;
        (_a = this.inputField) === null || _a === void 0 ? void 0 : _a.removeEventListener('focus', () => this._onFocus(false));
        (_b = this.inputField) === null || _b === void 0 ? void 0 : _b.removeEventListener('blur', () => this._onBlur());
        (_c = this.inputField) === null || _c === void 0 ? void 0 : _c.removeEventListener('keypress', this._preventNonNumericalInput);
        this._observer.disconnect();
        (_d = this._dropdownElement) === null || _d === void 0 ? void 0 : _d.remove();
    }
    get isActive() {
        return !!this.value || typeof this.value === 'boolean' || this.isFocused;
    }
    _setAriaDescriptionId() {
        this.inputField.removeAttribute('aria-describedby');
        let type = null;
        if (this.valid && !this.value && this.hint) {
            type = 'hint';
        }
        if (!this.valid) {
            type = 'error';
        }
        if (type) {
            this.inputField.setAttribute('aria-describedby', `${type}-${this.inputId}`);
        }
    }
    _calculateElementWidths() {
        this.labelWidth = !!this.label ? this._labelRef.scrollWidth * 0.75 + 6 : 0;
        this.preSlotWidth = this.inputField.offsetLeft;
    }
    _onReset() {
        requestAnimationFrame(() => {
            if (this.inputField && !this.labelOnTop) {
                if (!!this.placeholder &&
                    !this.value &&
                    (this.active || this.isFocused)) {
                    this.inputField.placeholder = this.placeholder;
                    return;
                }
                this.inputField.placeholder =
                    !this.label && !this.value && !!this.placeholder
                        ? this.placeholder
                        : '';
            }
        });
    }
    _preventNonNumericalInput(event) {
        if (this.type !== 'number')
            return;
        if (!event.key.match(/^[0-9,\.-]+$/)) {
            event.preventDefault();
        }
    }
    _renderBorders() {
        if (this.shadow)
            return;
        const classes = {
            active: this.isActive || this.active,
            'label-on-top': this.labelOnTop,
        };
        return (h("fieldset", { "aria-hidden": "true" }, h("legend", { class: classes, style: {
                '--_c-input-legend-width': this.labelWidth + 'px',
            } }, h("span", { class: "notranslate" }))));
    }
    _renderLabel() {
        if (!this.label)
            return;
        const classes = {
            active: this.isActive,
            filled: !!this.value || typeof this.value === 'boolean',
            'label-on-top': this.labelOnTop,
        };
        return (h("label", { htmlFor: this.inputId, ref: (el) => (this._labelRef = el), class: classes }, this.label, this.required && h("span", null, "\u00A0*")));
    }
    get inputField() {
        var _a;
        return (_a = this.el) === null || _a === void 0 ? void 0 : _a.querySelector('.c-input__input');
    }
    _updateStatusText() {
        if (this._debounce !== null) {
            clearTimeout(this._debounce);
            this._debounce = null;
        }
        this._debounce = window.setTimeout(() => {
            this.statusText = this.valid ? '' : `Error: ${this.validation}`;
            this._debounce = null;
        }, 1400);
    }
    render() {
        const containerClasses = {
            'c-input': true,
            'c-input--disabled': this.disabled,
            'c-input--shadow': this.shadow,
            'c-input--label-on-top': this.labelOnTop,
            'c-input--textarea': this.rows > 1,
            'c-input--error': !this.valid,
            'c-input--active': this.isFocused || this.active,
            filled: !!this.value,
            [`c-input--${this.variant}`]: true,
        };
        return (h(Host, { key: '2fdc7e237b1e2b0837e72510ddb8240b2ed15198', disabled: this.disabled }, h("div", { key: '3f1128cf26da49d0eab24e688d74d5a6e417d195', id: 'announce-' + this.inputId, class: "visuallyhidden", "aria-live": "polite", "aria-atomic": "true" }, this.statusText), h("div", { key: 'bc79e784977c38b2cd8d80a649da95d10ffff11d', class: containerClasses }, this.labelOnTop && this._renderLabel(), h("div", { key: 'dd56297fba8a8e9d772f2ae49292b0a1fb195eff', class: "c-input__control" }, h("div", { key: '0a193e025daa0832c4cb36c107b25836a583a629', class: "c-input__slot", onClick: () => this._onFocus() }, this._renderBorders(), h("div", { key: '17c694469e8d6ee7a48d69d45ab05136bf46c2d2', class: "c-input__field", style: {
                '--_c-input-label-position': this.preSlotWidth + 'px',
            } }, h("slot", { key: '91427605d55129e2f804fc2b8bf2e0ab747e151f', name: "pre" }), !this.labelOnTop && this._renderLabel(), h("slot", { key: '1ed436ada4e6dbe6e88805422ef61aaee09c30ba' }))), this.variant === 'select' && h("slot", { key: '232f92cbeb9ca7730efc488b393886058ce71148', name: "dropdown" }), !this.hideDetails && (h("c-message", { key: 'd66d4192a8636ddd90fc9ec2e3638e9e9b54d69a', hint: this.hint, inputId: this.inputId, valid: this.valid, validation: this.validation }))))));
    }
    static get is() { return "c-input"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-input.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-input.css"]
        };
    }
    static get properties() {
        return {
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Active state"
                },
                "getter": false,
                "setter": false,
                "attribute": "active",
                "reflect": false,
                "defaultValue": "false"
            },
            "automaticFocus": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "autofocus"
                        }],
                    "text": "Auto focus the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "autofocus",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "hideDetails": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hide the hint and error messages"
                },
                "getter": false,
                "setter": false,
                "attribute": "hide-details",
                "reflect": false,
                "defaultValue": "false"
            },
            "hint": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hint text for the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "hint",
                "reflect": false,
                "defaultValue": "''"
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "inputId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Id of the input element"
                },
                "getter": false,
                "setter": false,
                "attribute": "input-id",
                "reflect": false
            },
            "items": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "CSelectItem[]",
                    "resolved": "CSelectItem[]",
                    "references": {
                        "CSelectItem": {
                            "location": "import",
                            "path": "../../types",
                            "id": "src/types/index.ts::CSelectItem"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Items for the dropdown"
                },
                "getter": false,
                "setter": false
            },
            "itemsPerPage": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Items per page before adding scroll"
                },
                "getter": false,
                "setter": false,
                "attribute": "items-per-page",
                "reflect": false,
                "defaultValue": "6"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false
            },
            "labelOnTop": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label on top of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "label-on-top",
                "reflect": false,
                "defaultValue": "false"
            },
            "max": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Maximum value on a numeric input"
                },
                "getter": false,
                "setter": false,
                "attribute": "max",
                "reflect": false,
                "defaultValue": "null"
            },
            "min": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Minimum value on a numeric input"
                },
                "getter": false,
                "setter": false,
                "attribute": "min",
                "reflect": false,
                "defaultValue": "null"
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Name of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "placeholder": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Placeholder of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "placeholder",
                "reflect": false
            },
            "readonly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mark as readonly"
                },
                "getter": false,
                "setter": false,
                "attribute": "readonly",
                "reflect": false,
                "defaultValue": "false"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the input as required"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            },
            "rows": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Rows on the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "rows",
                "reflect": false,
                "defaultValue": "1"
            },
            "shadow": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Shadow variant of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "shadow",
                "reflect": false,
                "defaultValue": "false"
            },
            "step": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Step size on a numeric input"
                },
                "getter": false,
                "setter": false,
                "attribute": "step",
                "reflect": false,
                "defaultValue": "null"
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Type of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false
            },
            "valid": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the valid\u00EDty of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "valid",
                "reflect": false,
                "defaultValue": "true"
            },
            "validate": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Manual validation"
                },
                "getter": false,
                "setter": false,
                "attribute": "validate",
                "reflect": false,
                "defaultValue": "false"
            },
            "validateOnBlur": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Validate the input on blur"
                },
                "getter": false,
                "setter": false,
                "attribute": "validate-on-blur",
                "reflect": false,
                "defaultValue": "false"
            },
            "validation": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Custom validation message"
                },
                "getter": false,
                "setter": false,
                "attribute": "validation",
                "reflect": false,
                "defaultValue": "'Required field'"
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "string | number | boolean | CSelectItem | CAutocompleteItem",
                    "resolved": "CSelectItem & { ref?: HTMLElement; } | boolean | number | string | { name: string; value: string | number; disabled?: boolean; }",
                    "references": {
                        "CSelectItem": {
                            "location": "import",
                            "path": "../../types",
                            "id": "src/types/index.ts::CSelectItem"
                        },
                        "CAutocompleteItem": {
                            "location": "import",
                            "path": "../../types",
                            "id": "src/types/index.ts::CAutocompleteItem"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Value of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'text' | 'select'",
                    "resolved": "\"select\" | \"text\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Variant"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false,
                "defaultValue": "'text'"
            }
        };
    }
    static get states() {
        return {
            "isFocused": {},
            "labelWidth": {},
            "preSlotWidth": {},
            "statusText": {},
            "currentIndex": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emit changes to the parent"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "itemClick",
                "name": "itemClick",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit click to the parent"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "dropdownClose",
                "name": "dropdownClose",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit close to the parent"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get methods() {
        return {
            "reset": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }]
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "valid",
                "methodName": "onValidChange"
            }, {
                "propName": "validation",
                "methodName": "onValidationMessageChange"
            }, {
                "propName": "value",
                "methodName": "onValueChange"
            }, {
                "propName": "placeholder",
                "methodName": "onPlaceholderChange"
            }];
    }
}
//# sourceMappingURL=c-input.js.map
