import { Host, h } from "@stencil/core";
export class CListItem {
    constructor() {
        this.active = false;
        this.disabled = false;
        this.disabledByParent = false;
        this.hoverable = false;
        this.ripple = false;
        this.target = '_blank';
        this._onClick = (event, center = false) => {
            if (this.disabled) {
                event.preventDefault();
                return;
            }
            if (!this.ripple)
                return;
            this.el.shadowRoot
                .querySelector('c-ripple')
                .createRipple(event, this.el, center);
        };
        this._onKeyup = (event) => {
            if ([' ', 'Enter'].includes(event.key)) {
                this._onClick(event, true);
            }
        };
    }
    onActiveChange(active) {
        const title = this.el.querySelector('c-list-item-title');
        if (!title)
            return;
        title.active = active;
    }
    get _slots() {
        const hasPreSlot = !!this.el.querySelector('[slot="pre"]');
        const hasPostSlot = !!this.el.querySelector('[slot="post"]');
        return {
            pre: hasPreSlot,
            post: hasPostSlot,
        };
    }
    get _tabindex() {
        if (this.disabled)
            return -1;
        if (this.ripple && !this.href)
            return 0;
        return null;
    }
    render() {
        const Tag = !!this.href ? 'a' : 'div';
        const classes = {
            'c-list-item': true,
            'c-list-item--active': this.active,
            'c-list-item--disabled': this.disabled,
            'c-list-item--hoverable': this.ripple || !!this.href || this.hoverable,
            'c-list-item--ripple': this.ripple,
        };
        let linkAttributes = {};
        if (!!this.href) {
            linkAttributes = { href: this.href, target: this.target };
        }
        return (h(Host, Object.assign({ key: 'd9bb04d68894dc079c55526b620fd43f6e2652df', role: "listitem", "aria-disabled": (!!this.disabled).toString(), onClick: this._onClick, onKeyup: this._onKeyup, class: classes }, (!!this.disabled ? { disabled: 'true' } : {}), (!!this.disabledByParent ? { 'data-disabled': 'true' } : {}), ([0, -1].includes(this._tabindex)
            ? { tabindex: this._tabindex }
            : {})), h(Tag, Object.assign({ key: '05c999e4b845563f80e87031f0c5530aafe505f5' }, linkAttributes, { class: "c-list-item__content" }), this._slots.pre && h("slot", { key: '5a18d84192c3c4b2a002525bd3e60b40d663c2c1', name: "pre" }), h("slot", { key: '120a48ac799a984b710a06be56712676fc9c95a2' }), this._slots.post && h("slot", { key: 'e5ae03bca09f1a2a93d44dfc43ae6b0165dcfe4c', name: "post" }), this.ripple && h("c-ripple", { key: '8299510748b453ee5fa39c30f2f60f9a8a937f71' }))));
    }
    static get is() { return "c-list-item"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-list-item.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-list-item.css"]
        };
    }
    static get properties() {
        return {
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the item active"
                },
                "getter": false,
                "setter": false,
                "attribute": "active",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the item"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabledByParent": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Disabled by the parent list"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled-by-parent",
                "reflect": false,
                "defaultValue": "false"
            },
            "hoverable": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Display background color on hover"
                },
                "getter": false,
                "setter": false,
                "attribute": "hoverable",
                "reflect": false,
                "defaultValue": "false"
            },
            "ripple": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Add ripple effect to the item"
                },
                "getter": false,
                "setter": false,
                "attribute": "ripple",
                "reflect": false,
                "defaultValue": "false"
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Hyperlink url"
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hyperlink target"
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false,
                "defaultValue": "'_blank'"
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "active",
                "methodName": "onActiveChange"
            }];
    }
}
//# sourceMappingURL=c-list-item.js.map
