import { h, } from "@stencil/core";
export class CModal {
    constructor() {
        this.value = false;
        this.dismissable = false;
        this.width = 600;
        this.zIndex = 10;
        this.disableBackdropBlur = false;
        this.innerValue = false;
        this.animateModal = false;
        this.standaloneMode = false;
        this._debounce = null;
        this._animationsDisabled = false;
        this._handleBackdrop = () => {
            var _a, _b, _c;
            const cMain = document.body.querySelector('c-main');
            if (!cMain) {
                this.standaloneMode = true;
                return;
            }
            this.standaloneMode = false;
            this._backdropElement || (this._backdropElement = cMain.shadowRoot.querySelector('c-backdrop'));
            if (!this._backdropElement) {
                return;
            }
            this._backdropElement.setAttribute('disable-backdrop-blur', this.disableBackdropBlur.toString());
            (_c = (_b = (_a = this._backdropElement) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelector('.c-backdrop')) === null || _c === void 0 ? void 0 : _c.classList.remove('closing');
        };
        this._handleShow = () => {
            requestAnimationFrame(() => {
                var _a, _b, _c, _d, _e, _f;
                this._handleBackdrop();
                if (!this._animationsDisabled) {
                    (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.addEventListener('animationend', this._onDialogOpened);
                    (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.add('opening');
                    (_e = (_d = (_c = this._backdropElement) === null || _c === void 0 ? void 0 : _c.shadowRoot) === null || _d === void 0 ? void 0 : _d.querySelector('.c-backdrop')) === null || _e === void 0 ? void 0 : _e.classList.add('opening');
                }
                (_f = this._dialog) === null || _f === void 0 ? void 0 : _f.showModal();
            });
        };
        this._onDialogOpened = () => {
            var _a, _b;
            (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.removeEventListener('animationend', this._onDialogOpened);
            (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.remove('opening');
        };
        this._handleClose = () => {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            if (this._animationsDisabled) {
                this._onDialogClosed();
                return;
            }
            (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.addEventListener('animationend', this._onDialogClosed);
            (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.add('closing');
            (_e = (_d = (_c = this._backdropElement) === null || _c === void 0 ? void 0 : _c.shadowRoot) === null || _d === void 0 ? void 0 : _d.querySelector('.c-backdrop')) === null || _e === void 0 ? void 0 : _e.classList.remove('opening');
            (_h = (_g = (_f = this._backdropElement) === null || _f === void 0 ? void 0 : _f.shadowRoot) === null || _g === void 0 ? void 0 : _g.querySelector('.c-backdrop')) === null || _h === void 0 ? void 0 : _h.classList.add('closing');
        };
        this._onDialogClosed = () => {
            var _a, _b, _c, _d, _e, _f;
            if (!this._animationsDisabled) {
                (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.removeEventListener('animationend', this._onDialogClosed);
                (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.remove('closing');
                (_e = (_d = (_c = this._backdropElement) === null || _c === void 0 ? void 0 : _c.shadowRoot) === null || _d === void 0 ? void 0 : _d.querySelector('.c-backdrop')) === null || _e === void 0 ? void 0 : _e.classList.remove('closing');
            }
            (_f = this._dialog) === null || _f === void 0 ? void 0 : _f.close();
            if (!document.fullscreenElement)
                return;
            document.exitFullscreen();
        };
        this._handleClickOutside = () => {
            this._dialog.addEventListener('click', (e) => {
                if (e.clientX === 0 && e.clientY === 0)
                    return;
                const dialogDimensions = this._dialog.getBoundingClientRect();
                if (e.clientX < dialogDimensions.left ||
                    e.clientX > dialogDimensions.right ||
                    e.clientY < dialogDimensions.top ||
                    e.clientY > dialogDimensions.bottom) {
                    if (!this.dismissable) {
                        this._dialog.classList.add('nudging');
                        if (this._debounce !== null) {
                            clearTimeout(this._debounce);
                            this._debounce = null;
                        }
                        this._debounce = window.setTimeout(() => {
                            this._dialog.classList.remove('nudging');
                            this._debounce = null;
                        }, 150);
                        return;
                    }
                    this._handleClose();
                    this.changeValue.emit(false);
                }
            });
        };
        this._handleKeyDown = (e) => {
            if (e.keyCode === 27) {
                e.preventDefault();
                this._handleClose();
                this.changeValue.emit(false);
            }
        };
    }
    onValueChange(value) {
        if (value) {
            this._handleShow();
            return;
        }
        this._handleClose();
    }
    componentWillLoad() {
        this.innerValue = this.value;
        const width = isNaN(this.width) ? this.width : `${this.width}px`;
        this.el.style.setProperty('--_c-modal-width', `${width}`);
    }
    componentDidLoad() {
        const query = window.matchMedia('(prefers-reduced-motion: reduce)');
        this._animationsDisabled = query.matches;
        this._handleClickOutside();
        if (this.value) {
            this._handleShow();
        }
    }
    disconnectedCallback() {
        const dialogs = document.querySelectorAll('c-dialog');
        if (!dialogs.length) {
            this._handleClose();
        }
    }
    render() {
        const dialogStyle = {
            'z-index': `${this.zIndex}`,
        };
        const classes = {
            'c-modal': true,
            'c-modal--standalone': this.standaloneMode,
            'c-modal--backdrop-blur': !this.disableBackdropBlur,
        };
        return (h("dialog", { key: '8de37abe52c89f3809ffea04150c029feea47f90', ref: (el) => (this._dialog = el), style: dialogStyle, class: classes, onKeyDown: this._handleKeyDown }, h("slot", { key: '086797c254e2778bbbe74d4776fe6ce931d738cb' })));
    }
    static get is() { return "c-modal"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-modal.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-modal.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is the modal visible"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false,
                "defaultValue": "false"
            },
            "dismissable": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Dismissed when touching/clicking outside the content"
                },
                "getter": false,
                "setter": false,
                "attribute": "dismissable",
                "reflect": false,
                "defaultValue": "false"
            },
            "width": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "string | number",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Width of the dialog. Numeric value is considered as pixel value (400 -> 400px)"
                },
                "getter": false,
                "setter": false,
                "attribute": "width",
                "reflect": false,
                "defaultValue": "600"
            },
            "zIndex": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Z-index of the modal"
                },
                "getter": false,
                "setter": false,
                "attribute": "z-index",
                "reflect": false,
                "defaultValue": "10"
            },
            "disableBackdropBlur": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable backdrop blur effect"
                },
                "getter": false,
                "setter": false,
                "attribute": "disable-backdrop-blur",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "innerValue": {},
            "animateModal": {},
            "standaloneMode": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Triggered when value is changed"
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "onValueChange"
            }];
    }
}
//# sourceMappingURL=c-modal.js.map
