import { Host, h, } from "@stencil/core";
import { mdiChevronDown, mdiClose } from "@mdi/js";
export class CSelect {
    constructor() {
        this.items = [];
        this.value = null;
        this.clearable = false;
        this.disabled = false;
        this.labelOnTop = false;
        this.placeholder = '';
        this.hideDetails = false;
        this.hint = '';
        this.loading = false;
        this.required = false;
        this.valid = true;
        this.validate = false;
        this.validateOnBlur = false;
        this.validation = 'Required field';
        this.shadow = false;
        this.returnObject = false;
        this.itemsPerPage = 6;
        this.currentIndex = null;
        this.dropdownVisible = false;
        this.statusText = '';
        this.optionElementsExist = false;
        this._debounce = null;
        this._lastKeyPressTime = null;
        this._searchString = '';
        this._toggleDropdown = (event) => {
            var _a;
            event.stopPropagation();
            if (this.dropdownVisible) {
                (_a = this._dropdownElement) === null || _a === void 0 ? void 0 : _a.close();
                return;
            }
            this._dropdownElement.open();
        };
        this._onButtonKeyDown = (src, event) => {
            event.stopPropagation();
            if (event.key !== 'Tab')
                event.preventDefault();
            if (['Enter', ' '].includes(event.key)) {
                if (src === 'chevron') {
                    this._toggleDropdown(event);
                    return;
                }
                this._onReset(event);
                requestAnimationFrame(() => {
                    this._inputElement.focus();
                });
            }
        };
        this._onSlotChange = () => {
            this.optionElements = this.el.querySelectorAll('c-option');
            if (this.optionElements.length && !this.optionElementsExist) {
                this.optionElementsExist = true;
            }
            const selection = Array.from(this.optionElements).find((option) => option.selected);
            if (selection) {
                this.value = this.returnObject
                    ? { name: selection.name, value: selection.value }
                    : selection.value;
                this.changeValue.emit(this.value);
                this.internals.setFormValue(selection.value.toString());
            }
        };
        this._onReset = (event) => {
            event.stopPropagation();
            this.changeValue.emit(null);
            this.internals.setFormValue(null);
            this.currentIndex = null;
            this._selectionElement.classList.remove('c-input-menu__selection--show');
            this._selectionElement.replaceChildren(null);
            this._cInputElement.reset();
            this._inputElement.focus();
            this._dropdownElement.updateList(true);
        };
        this._onInputFocus = () => {
            if (this.disabled)
                return;
            this._updateStatusText();
        };
    }
    get _id() {
        return this.hostId || `select_${CSelect._uniqueId}`;
    }
    get _items() {
        return this.optionElementsExist ? this.optionElements : this.items;
    }
    get _value() {
        var _a, _b, _c, _d;
        if (!this.value)
            return '';
        if (!this.returnObject &&
            !['number', 'string'].includes(typeof this.value)) {
            console.warn(`[C-SELECT] The value should be of type 'number' or 'string' when return-object is not used.`);
            return '';
        }
        if (!this.returnObject &&
            ['number', 'string'].includes(typeof this.value)) {
            return (_b = (_a = Array.from(this._items)) === null || _a === void 0 ? void 0 : _a.find((item) => item.value === this.value)) === null || _b === void 0 ? void 0 : _b.name;
        }
        return (_d = (_c = Array.from(this._items)) === null || _c === void 0 ? void 0 : _c.find((item) => item.value === this.value.value)) === null || _d === void 0 ? void 0 : _d.name;
    }
    async reset() {
        this.changeValue.emit(null);
        this.internals.setFormValue(null);
        this._dropdownElement.updateList(true);
    }
    handleKeyDown(event) {
        var _a, _b, _c;
        const alphanumeric = /^[0-9a-zA-Z ]+$/;
        if (this.disabled)
            return;
        if (event.key.match(alphanumeric) && event.key.length === 1) {
            if (!this.dropdownVisible) {
                this._dropdownElement.open();
            }
            requestAnimationFrame(() => {
                if (Date.now() - this._lastKeyPressTime > 3000) {
                    this._searchString = event.key;
                }
                else {
                    this._searchString += event.key;
                }
                this._lastKeyPressTime = Date.now();
                const selectionIndex = this._getSelectionIndex(this._searchString);
                this.currentIndex = selectionIndex >= 0 ? selectionIndex : null;
                return;
            });
        }
        if (event.key === 'Escape') {
            (_a = this._dropdownElement) === null || _a === void 0 ? void 0 : _a.close();
            this._inputElement.focus();
            if (!this.value) {
                this.currentIndex = null;
            }
            return;
        }
        if (event.key === 'Tab') {
            (_b = this._dropdownElement) === null || _b === void 0 ? void 0 : _b.close();
        }
        if (event.key === 'ArrowDown') {
            event.preventDefault();
            if (!this._items.length)
                return;
            if (!this.dropdownVisible) {
                this._dropdownElement.open();
                if (this.value) {
                    this.currentIndex = this._getSelectionIndex(this._value);
                }
                return;
            }
            requestAnimationFrame(() => {
                this.currentIndex =
                    this.currentIndex === null
                        ? 0
                        : Math.min(this.currentIndex + 1, this._items.length - 1);
                this._dropdownElement.focusItem(this.currentIndex);
            });
        }
        if (event.key === 'ArrowUp') {
            event.preventDefault();
            if (this.currentIndex === 0) {
                (_c = this._dropdownElement) === null || _c === void 0 ? void 0 : _c.close();
                this._inputElement.focus();
            }
            if (!this.dropdownVisible) {
                this._dropdownElement.open();
                if (this.value) {
                    this.currentIndex = this._getSelectionIndex(this._value);
                }
                return;
            }
            this.currentIndex =
                this.currentIndex === null
                    ? this._items.length - 1
                    : Math.max(this.currentIndex - 1, 0);
            this._dropdownElement.focusItem(this.currentIndex);
        }
        if (event.key === ' ') {
            event.preventDefault();
        }
        if (event.key === 'Enter') {
            event.preventDefault();
            if (this.currentIndex === null)
                return;
            this._dropdownElement.selectItem(this.currentIndex);
        }
        if (event.key === 'Home' && this.dropdownVisible) {
            this.currentIndex = 0;
        }
        if (event.key === 'End' && this.dropdownVisible) {
            this.currentIndex = this._items.length - 1;
        }
    }
    onDropdownStateChange(event) {
        const isOpen = event.detail;
        this.dropdownVisible = isOpen;
    }
    onValueChanged(value) {
        var _a;
        if (!value) {
            if (this.optionAsSelection)
                (_a = this._selectionElement) === null || _a === void 0 ? void 0 : _a.replaceChildren();
            return;
        }
        this._selectOption(this.returnObject ? value : { name: value, value: value });
    }
    onSelectOption(event) {
        var _a, _b;
        if (this.returnObject &&
            this.value.value === event.detail.value) {
            (_a = this._dropdownElement) === null || _a === void 0 ? void 0 : _a.close();
        }
        if (!this.returnObject && this.value === event.detail.value) {
            (_b = this._dropdownElement) === null || _b === void 0 ? void 0 : _b.close();
        }
        this._setValue(event.detail);
    }
    _getSelectionIndex(searchString) {
        return Array.from(this._items).findIndex((i) => i.name.toLowerCase().startsWith(searchString.toLowerCase()));
    }
    _selectOption({ value, name }) {
        var _a, _b, _c;
        (_a = this._dropdownElement) === null || _a === void 0 ? void 0 : _a.close();
        const selection = this._setCurrentIndex({ name, value });
        if (this.optionElementsExist && this.optionAsSelection && selection) {
            const clone = selection.cloneNode(true);
            this._selectionElement.classList.add('c-input-menu__selection--show');
            this._selectionElement.replaceChildren(clone);
        }
        (_b = this._dropdownElement) === null || _b === void 0 ? void 0 : _b.updateList();
        (_c = this._inputElement) === null || _c === void 0 ? void 0 : _c.focus();
    }
    _setValue({ value, name }) {
        this.value = this.returnObject ? { name, value } : value;
        this.changeValue.emit(this.value);
        this.internals.setFormValue(value);
    }
    _setCurrentIndex({ value, name }) {
        let selection = null;
        Array.from(this._items).forEach((item, index) => {
            const selected = item.value === value && item.name === name;
            if (this.optionElementsExist) {
                item.selected = selected;
            }
            if (selected) {
                this.currentIndex = index;
                selection = item;
            }
        });
        return selection;
    }
    _updateInput() {
        this._dropdownElement.open();
        this._dropdownElement.updateList();
    }
    _updateStatusText() {
        if (this._debounce !== null) {
            clearTimeout(this._debounce);
            this._debounce = null;
        }
        this._debounce = window.setTimeout(() => {
            this.statusText = '';
            if (this.currentIndex === null) {
                this.statusText = this._items.length
                    ? `${this._items.length} option${this._items.length !== 1 ? 's' : ''} available`
                    : 'No options available';
            }
            const ending = !!this._items.length
                ? ', navigate using the up and down arrows'
                : '';
            this._dropdownElement.setStatusText(this.statusText + ending);
            this._debounce = null;
        }, 1400);
    }
    componentWillLoad() {
        CSelect._uniqueId += 1;
        this._inputId =
            'input_' +
                (this.hostId || this.label || this.placeholder).replace(/[^a-zA-Z0-9-_]/g, '');
    }
    componentDidLoad() {
        if (!this.value)
            return;
        const selection = Array.from(this._items).find((item) => {
            if (this.returnObject) {
                return (item.name === this.value.name &&
                    item.value === this.value.value);
            }
            return item.value === this.value;
        });
        if (selection) {
            this._setCurrentIndex({
                name: selection.name,
                value: selection.value.toString(),
            });
        }
    }
    _renderLoader() {
        return h("c-spinner", { color: "var(--_c-autocomplete-active-color)", size: 20 });
    }
    _renderChevron() {
        const classes = {
            'c-input-menu__chevron': true,
            'c-input-menu__chevron--active': this.dropdownVisible,
        };
        return (h("c-icon-button", { size: "x-small", class: classes, disabled: this.disabled, text: true, onClick: (event) => this._toggleDropdown(event), onKeyDown: (event) => this._onButtonKeyDown('chevron', event) }, h("c-icon", { path: mdiChevronDown, size: 24, key: "c-select--chevron-icon" })));
    }
    _renderInputElement() {
        var _a;
        return (h("div", { class: "c-input-menu__input" }, h("input", { type: "text", readonly: true, ref: (el) => (this._inputElement = el), "aria-expanded": this.dropdownVisible.toString(), "aria-owns": this._inputId + '-items', "aria-autocomplete": "list", autocomplete: "off", class: "c-input__input", role: "combobox", value: this._value, name: (_a = this.name) !== null && _a !== void 0 ? _a : null, disabled: this.disabled, onInput: () => this._updateInput(), onFocus: () => this._onInputFocus() }), h("div", { ref: (el) => (this._selectionElement = el), class: "c-input-menu__selection" })));
    }
    _renderReset() {
        return (h("c-icon-button", { "aria-label": "", size: "x-small", disabled: this.disabled, text: true, onClick: (event) => this._onReset(event), onKeyDown: (event) => this._onButtonKeyDown('reset', event) }, h("c-icon", { path: mdiClose, size: 20, key: "c-select--reset-icon" })));
    }
    render() {
        const itemType = this.optionElementsExist ? 'option' : 'item';
        return (h(Host, { key: '20dccd7cf894dd0bf68363aeff41b74ac4f92a07' }, h("c-dropdown", { key: '8728a250a33069a1d0161f3f6abba12f8eb3cf4b', ref: (el) => (this._dropdownElement = el), id: `${this._id}-dropdown`, index: this.currentIndex, "items-per-page": this.itemsPerPage, "dropdown-item-type": itemType, items: this._items, parent: this.el, type: "select" }, h("c-input", { key: '1a74b539fb5d34c1ade1ec5f41df8d7ded28bf6e', slot: "default", ref: (el) => (this._cInputElement = el), active: this.dropdownVisible, disabled: this.disabled, "hide-details": this.hideDetails, hint: this.hint, id: this.hostId, "input-id": this._inputId, label: this.label, "label-on-top": this.labelOnTop, name: this.name, placeholder: this.placeholder, required: this.required, shadow: this.shadow, valid: this.valid, validate: this.validate, "validate-on-blur": this.validateOnBlur, validation: this.validation, value: this.value, variant: "select", onClick: () => !this.disabled && this._dropdownElement.open() }, h("slot", { key: '7acfb9f02f4c3898e4a1a0321384881f2b2e2f35', name: "pre", slot: "pre" }), h("div", { key: 'a9c6c0b04bd72e8d47eb29a576a9546ab7b28662', class: "c-input__content" }, this._renderInputElement(), this.loading && this._renderLoader(), !this.loading &&
            this.value &&
            this.clearable &&
            this._renderReset(), !this.loading &&
            (!this.value || !this.clearable) &&
            this._renderChevron(), h("slot", { key: '7522681c6ad78399a851d3b6934041753080ab5b', onSlotchange: () => this._onSlotChange() })), h("slot", { key: '897920c1884bf2eebb9976925db4c8f6b51c2d06', name: "post", slot: "post" })))));
    }
    static get is() { return "c-select"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["c-select.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-select.css"]
        };
    }
    static get properties() {
        return {
            "items": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "CSelectItem[]",
                    "resolved": "CSelectItem[]",
                    "references": {
                        "CSelectItem": {
                            "location": "import",
                            "path": "../../types",
                            "id": "src/types/index.ts::CSelectItem"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Dropdown items"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "string | number | CSelectItem",
                    "resolved": "number | string | { name: string; value: string | number; disabled?: boolean; }",
                    "references": {
                        "CSelectItem": {
                            "location": "import",
                            "path": "../../types",
                            "id": "src/types/index.ts::CSelectItem"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Selected item"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false,
                "defaultValue": "null"
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the element"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "clearable": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Make the selected value clearable"
                },
                "getter": false,
                "setter": false,
                "attribute": "clearable",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Element label"
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false
            },
            "labelOnTop": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label on top of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "label-on-top",
                "reflect": false,
                "defaultValue": "false"
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Input field name"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "placeholder": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Placeholder text"
                },
                "getter": false,
                "setter": false,
                "attribute": "placeholder",
                "reflect": false,
                "defaultValue": "''"
            },
            "hideDetails": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hide the hint and error messages"
                },
                "getter": false,
                "setter": false,
                "attribute": "hide-details",
                "reflect": false,
                "defaultValue": "false"
            },
            "hint": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hint text for the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "hint",
                "reflect": false,
                "defaultValue": "''"
            },
            "loading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Show loading state"
                },
                "getter": false,
                "setter": false,
                "attribute": "loading",
                "reflect": false,
                "defaultValue": "false"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Show required validation"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            },
            "valid": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the valid\u00EDty of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "valid",
                "reflect": false,
                "defaultValue": "true"
            },
            "validate": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Manual validation"
                },
                "getter": false,
                "setter": false,
                "attribute": "validate",
                "reflect": false,
                "defaultValue": "false"
            },
            "validateOnBlur": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Validate the input on blur"
                },
                "getter": false,
                "setter": false,
                "attribute": "validate-on-blur",
                "reflect": false,
                "defaultValue": "false"
            },
            "validation": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Custom validation message"
                },
                "getter": false,
                "setter": false,
                "attribute": "validation",
                "reflect": false,
                "defaultValue": "'Required field'"
            },
            "shadow": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Shadow variant"
                },
                "getter": false,
                "setter": false,
                "attribute": "shadow",
                "reflect": false,
                "defaultValue": "false"
            },
            "returnObject": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Return object instead of value"
                },
                "getter": false,
                "setter": false,
                "attribute": "return-object",
                "reflect": false,
                "defaultValue": "false"
            },
            "itemsPerPage": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Items per page before adding scroll"
                },
                "getter": false,
                "setter": false,
                "attribute": "items-per-page",
                "reflect": false,
                "defaultValue": "6"
            },
            "optionAsSelection": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "false",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "display the option as selection (works only when c-option elements are used)"
                },
                "getter": false,
                "setter": false,
                "attribute": "option-as-selection",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "optionElements": {},
            "currentIndex": {},
            "dropdownVisible": {},
            "statusText": {},
            "optionElementsExist": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Triggered when option is selected"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get methods() {
        return {
            "reset": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "Reset select state",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "onValueChanged"
            }];
    }
    static get listeners() {
        return [{
                "name": "keydown",
                "method": "handleKeyDown",
                "target": undefined,
                "capture": false,
                "passive": true
            }, {
                "name": "dropdownStateChange",
                "method": "onDropdownStateChange",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "selectOption",
                "method": "onSelectOption",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
CSelect._uniqueId = 0;
//# sourceMappingURL=c-select.js.map
