import { h, Host, } from "@stencil/core";
import { mdiChevronRight } from "@mdi/js";
export class CSideNavigationItem {
    constructor() {
        this.target = null;
        this.loading = false;
        this._isSubItem = false;
        this._slotHasContent = false;
    }
    handleChange(event) {
        if (this._isSubItem) {
            event.stopPropagation();
            event.stopImmediatePropagation();
            event.preventDefault();
            this.active = !this.active;
        }
    }
    onActiveChange(active) {
        this._handleChildFocusableChange(active);
    }
    _handleChildFocusableChange(focusable) {
        if (!this._slotHasContent)
            return;
        Array.from(this.hostElement.querySelectorAll('[slot="sub-item"]')).forEach((child) => {
            child.ariaHidden = (!focusable).toString();
            child.focusable = focusable;
        });
    }
    _redirect(event) {
        if ((event instanceof KeyboardEvent && (event === null || event === void 0 ? void 0 : event.key) === 'Enter') ||
            !(event instanceof KeyboardEvent)) {
            if (this._isSubItem) {
                event.stopPropagation();
                event.stopImmediatePropagation();
                event.preventDefault();
            }
            this.itemChange.emit(event);
            if (!this._slotHasContent) {
                const sidenav = document.querySelector('c-side-navigation');
                sidenav.menuVisible = false;
            }
        }
    }
    _assignSubItemSlots() {
        const subItems = this.hostElement.querySelectorAll('c-side-navigation-item');
        Array.from(subItems).forEach((item) => {
            item.setAttribute('slot', 'sub-item');
        });
    }
    componentWillLoad() {
        this._assignSubItemSlots();
        this._slotHasContent =
            !!this.hostElement.querySelector('[slot="sub-item"]');
        this._isSubItem = !!this.hostElement.getAttribute('slot');
        this._handleChildFocusableChange(this.active);
    }
    componentDidLoad() {
        for (const node of this.hostElement.childNodes) {
            if (node.nodeName === '#text') {
                this._ariaLabel = node.nodeValue.trim();
                break;
            }
        }
        this._handleChildClasses();
    }
    _handleChildClasses() {
        if (!this._isSubItem)
            return;
        Array.from(this.hostElement.children)
            .filter((child) => child.tagName === 'C-SUB-NAVIGATION-ITEM')
            .forEach((child) => {
            child.classList.add('c-sub-navigation-item--sub-level');
        });
    }
    render() {
        var _a, _b;
        const classes = {
            'c-side-navigation-item': true,
            'c-side-navigation-item--parent': this._slotHasContent,
            active: this.active,
        };
        const subNavigationClasses = {
            subnavactive: this.active,
            'sub-item': !this.active,
        };
        const a11y = {
            role: 'menuitem',
            tabindex: '0',
        };
        if (this._slotHasContent) {
            a11y['aria-expanded'] = (_a = (!!this.active)) === null || _a === void 0 ? void 0 : _a.toString();
        }
        else if (this.active) {
            a11y['aria-current'] = 'page';
        }
        const Tag = !!this.href ? 'a' : 'div';
        const itemParams = Object.assign({}, (!!this.href ? { href: this.href, target: this.target } : {}));
        return (h(Host, Object.assign({ key: 'acadf1e69d3dbdef68b98d6f594d76bb10b6ce7d' }, a11y, { class: classes, onClick: (e) => this._redirect(e), onKeyDown: (e) => this._redirect(e) }), h("div", { key: '501bce072d81b99d60cac6c11c4ea39b9b75a8ae' }, h(Tag, Object.assign({ key: '411f2d331d06251c88c9035aaf4b326006b920ca' }, itemParams, { class: {
                'c-side-navigation-item__header': true,
                'c-side-navigation-item__header--expandable': this._slotHasContent,
            } }), this._slotHasContent && (h("c-icon", { key: 'fd3558e471e7a998b5610421444f04601903314b', class: "svg", path: mdiChevronRight })), h("div", { key: 'ae8c2082b44eae3b9032a011fa53a66ab5ddd980', class: "c-side-navigation-item__slot" }, h("slot", { key: '019be2a2bfc1271794a235cfeada9acfc8e5d6c4' }))), this._slotHasContent && (h("nav", { key: '24d51f07844e7aa21fc5803541dd7d2ee2fa0a26', role: "menubar", "aria-label": this._ariaLabel, "aria-expanded": (_b = (!!this.active)) === null || _b === void 0 ? void 0 : _b.toString(), class: subNavigationClasses }, h("slot", { key: '7ba1a4ab3d9441264a8c5ef7b905f8fbcaf9c8cd', name: "sub-item" }))), h("c-loader", { key: 'b3978b41f5c82af0da3e91f2c4b03a254d266ead', size: 32, hide: !this.loading, style: { pointerEvents: 'none' } }))));
    }
    static get is() { return "c-side-navigation-item"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-side-navigation-item.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-side-navigation-item.css"]
        };
    }
    static get properties() {
        return {
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Indicate active state"
                },
                "getter": false,
                "setter": false,
                "attribute": "active",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hyperlink url"
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hyperlink target"
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false,
                "defaultValue": "null"
            },
            "loading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Loading state"
                },
                "getter": false,
                "setter": false,
                "attribute": "loading",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "itemChange",
                "name": "itemChange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit changes to the c-accordion"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
    static get watchers() {
        return [{
                "propName": "active",
                "methodName": "onActiveChange"
            }];
    }
    static get listeners() {
        return [{
                "name": "itemChange",
                "method": "handleChange",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=c-side-navigation-item.js.map
