import { mdiArrowRight } from "@mdi/js";
import { Host, h } from "@stencil/core";
export class CSideNavigation {
    constructor() {
        this.menuVisible = false;
    }
    handleChange(event) {
        const slotted = this.host.querySelectorAll('c-side-navigation-item');
        const target = event.target;
        const { active } = target;
        slotted.forEach((item) => {
            if (item.querySelector('c-sub-navigation-item[slot="sub-item"]')) {
                item.active = false;
            }
        });
        if (target.querySelector('[slot="sub-item"]')) {
            target.active = !active;
        }
        else {
            target.active = true;
        }
    }
    _assignSubItemSlots() {
        const subItems = this.host.querySelectorAll('c-sub-navigation-item');
        Array.from(subItems).forEach((item) => {
            item.setAttribute('slot', 'sub-item');
        });
    }
    componentWillLoad() {
        this._assignSubItemSlots();
    }
    componentDidLoad() {
        const el = document.querySelector('body');
        ['click', 'keyup'].forEach((eventType) => {
            el.addEventListener(eventType, (e) => {
                if (e.target.matches('c-navigation-button')) {
                    if (eventType === 'click') {
                        this.menuVisible = !this.menuVisible;
                    }
                    else if (e instanceof KeyboardEvent && e.key === 'Enter') {
                        this.menuVisible = !this.menuVisible;
                    }
                }
            });
        });
        const addStyles = (el, styles) => Object.assign(el.style, styles);
        addStyles(this._containerElement, this.styles);
    }
    _closeMenu() {
        this.menuVisible = false;
    }
    render() {
        const classes = {
            'c-side-navigation': true,
            'hide-menu': !this.menuVisible,
            mobile: !!this.mobile,
            desktop: !this.mobile,
        };
        const containerClasses = {
            'c-side-navigation__content': true,
            'c-side-navigation__content--hidden': !this.menuVisible,
            'c-side-navigation__content--mobile': !!this.mobile,
            'c-side-navigation__content--desktop': !this.mobile,
        };
        return (h(Host, { key: 'cf2fa277c8ccdac4101f31644e4db5068fc05db7', class: { desktop: !this.mobile } }, h("div", { key: '60e6f8dc715dad39d9a83057bb561135027e625c', class: containerClasses }, h("nav", { key: '3ea6eefa300e4e7207ee9ea6f33d832b73089fec', ref: (el) => (this._containerElement = el), class: classes, role: "menubar" }, this.mobile && (h("div", { key: '72c1fca035c1daa2f3343bc0be73121db17f8dde', class: "c-side-navigation__burger" }, h("c-icon-button", { key: '3bf4f02c9413244f457b34e46014ca2fc2a7e5d5', text: true, inverted: true, onClick: () => this._closeMenu() }, h("span", { key: '717ec7f476ead0e4f587ff0f5e605d5f253b2313', class: "visuallyhidden" }, "Close sidemenu"), h("c-icon", { key: '5618860c176a3cdab9d9f61296fa4a2fbff7abe2', path: mdiArrowRight })))), h("div", { key: 'a913ef3f51e33c4a3c75d9ba2e1b20bb95707293', class: {
                'c-side-navigation__wrapper': true,
                'c-side-navigation__wrapper--mobile': !!this.mobile,
            } }, h("slot", { key: '5f49917e05cce01e40a4ee956616b6a906fc5a47' }), h("div", { key: 'ef2d8c5a734e3c03685259f2afc906d4a91c22b4', class: "vertical-spacer" }), h("slot", { key: '63e03f24f76aa310f674ded85a0be81d2fa8a432', name: "bottom" })))), this.menuVisible && this.mobile && (h("div", { key: '3a51049487f8b8bad81e0cd8760a1bd12ed8af78', class: "c-overlay c-fade-in", onClick: () => this._closeMenu() }))));
    }
    static get is() { return "c-side-navigation"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-side-navigation.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-side-navigation.css"]
        };
    }
    static get properties() {
        return {
            "styles": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "{ [key: string]: string }",
                    "resolved": "{ [key: string]: string; }",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Background styles"
                },
                "getter": false,
                "setter": false
            },
            "mobile": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mobile version"
                },
                "getter": false,
                "setter": false,
                "attribute": "mobile",
                "reflect": false
            },
            "menuVisible": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mobile version menu visibility"
                },
                "getter": false,
                "setter": false,
                "attribute": "menu-visible",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get elementRef() { return "host"; }
    static get listeners() {
        return [{
                "name": "itemChange",
                "method": "handleChange",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=c-side-navigation.js.map
