import { Host, h, } from "@stencil/core";
export class CSlider {
    constructor() {
        this.max = '100';
        this.min = '0';
        this.step = '1';
        this.value = '50';
        this.unit = '%';
        this.ticks = false;
        this.labels = false;
        this.disableTooltip = false;
        this.disabled = false;
        this.segments = '10';
        this.tickPositions = [];
    }
    onSegmentChange() {
        this._calculateTickPositions();
    }
    onValueChange(value) {
        this._calculateTrackPosition();
        requestAnimationFrame(() => {
            this._inputElement.value = value.toString();
        });
    }
    _formatNumber(number, decimals = 0) {
        return new Intl.NumberFormat('fi-FI', {
            maximumFractionDigits: decimals,
            minimumFractionDigits: decimals,
        }).format(number);
    }
    _calculateTickPositions() {
        this.tickPositions = [...new Array(+this.segments + 1)].map((_, index) => {
            const fraction = +this.max / +this.segments;
            return (index * fraction).toString();
        });
    }
    _calculateTrackPosition() {
        this.trackPosition =
            ((+this.value - +this.min) / (+this.max - +this.min)) * 100;
    }
    _onInput(event) {
        const { value } = event.target;
        this.changeValue.emit(typeof this.value === 'number' ? +value : value);
        this._calculateTrackPosition();
    }
    _isActive(value) {
        return this.trackPosition >= (100 / +this.max) * value;
    }
    componentWillLoad() {
        CSlider._uniqueId += 1;
    }
    componentDidLoad() {
        this._calculateTrackPosition();
        this._calculateTickPositions();
        requestAnimationFrame(() => {
            this._inputElement.value = this.value.toString();
        });
    }
    render() {
        const classes = {
            'c-slider': true,
            'c-slider--labels': this.labels,
        };
        const styles = {
            '--_c-slider-position': `${this.trackPosition}`,
        };
        return (h(Host, { key: 'de4f8e8ddb8e57f89f278942b450a974bc00df40', class: classes, style: styles }, h("div", { key: '24da9fefc72d1de5a58451c98f96db6e285cddf1' }, !!this.label && (h("label", { key: '0170444fe36d6af7ff0870136fd13c23af2ac714', class: "c-slider__label" }, !!this.label && this.label, " ", this.ariaLabelInternal)), h("div", { key: '27a54e2083b39664a42c3cf71d6aae52153552fb', class: "c-slider__wrapper" }, !this.disableTooltip && (h("div", { key: '0d5af91be72ba98fa328f6a63db3c63d0dc8ee10', class: "c-slider__tooltip-wrapper", "aria-hidden": "true" }, h("span", { key: '4def586e336b95ce08d3f0f53860449a47f3a7f0', "data-tooltip": `${this._formatNumber(+this.value)}${this.unit}` }))), h("input", { key: '45153c63b7eea4a41f4099a91b223c5d63037d75', ref: (el) => (this._inputElement = el), "aria-label": this.ariaLabelInternal || this.label, "aria-valuenow": this.value, "aria-valuetext": `${this.value}${this.unit}`, "aria-valuemin": this.min, "aria-valuemax": this.max, type: "range", name: this.hostName, id: this.hostId || `c-slider__${CSlider._uniqueId}`, min: this.min, max: this.max, step: this.step, disabled: this.disabled, onInput: (event) => this._onInput(event) })), h("div", { key: 'da6a0e89f640907ef6a6a825f5046b0839126e0e', class: {
                'c-slider__ticks': true,
                'c-slider__ticks--disabled': this.disabled,
            }, "aria-hidden": "true" }, this.tickPositions.map((position) => (h("span", { class: {
                active: this._isActive(Math.round(+position)),
                ticks: this.ticks,
                labels: this.labels,
            }, "data-value": this._formatNumber(Math.round(+position)) })))))));
    }
    static get is() { return "c-slider"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-slider.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-slider.css"]
        };
    }
    static get properties() {
        return {
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the element"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "hostName": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "name"
                        }],
                    "text": "Id of the element"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "ariaLabelInternal": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "aria-label"
                        }],
                    "text": "Aria label"
                },
                "getter": false,
                "setter": false,
                "attribute": "aria-label",
                "reflect": false
            },
            "max": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Max value"
                },
                "getter": false,
                "setter": false,
                "attribute": "max",
                "reflect": false,
                "defaultValue": "'100'"
            },
            "min": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Min value"
                },
                "getter": false,
                "setter": false,
                "attribute": "min",
                "reflect": false,
                "defaultValue": "'0'"
            },
            "step": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Step"
                },
                "getter": false,
                "setter": false,
                "attribute": "step",
                "reflect": false,
                "defaultValue": "'1'"
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "string | number",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Value"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false,
                "defaultValue": "'50'"
            },
            "unit": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Unit"
                },
                "getter": false,
                "setter": false,
                "attribute": "unit",
                "reflect": false,
                "defaultValue": "'%'"
            },
            "ticks": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Thow ticks"
                },
                "getter": false,
                "setter": false,
                "attribute": "ticks",
                "reflect": false,
                "defaultValue": "false"
            },
            "labels": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Show tick labels"
                },
                "getter": false,
                "setter": false,
                "attribute": "labels",
                "reflect": false,
                "defaultValue": "false"
            },
            "disableTooltip": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable tooltip"
                },
                "getter": false,
                "setter": false,
                "attribute": "disable-tooltip",
                "reflect": false,
                "defaultValue": "false"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label of the slider"
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the slider"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "segments": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Segment count"
                },
                "getter": false,
                "setter": false,
                "attribute": "segments",
                "reflect": false,
                "defaultValue": "'10'"
            }
        };
    }
    static get states() {
        return {
            "trackPosition": {},
            "tickPositions": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emit value changes to parent"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "segments",
                "methodName": "onSegmentChange"
            }, {
                "propName": "value",
                "methodName": "onValueChange"
            }];
    }
}
CSlider._uniqueId = 0;
//# sourceMappingURL=c-slider.js.map
