import { Host, h, } from "@stencil/core";
export class CSteps {
    constructor() {
        this.isMobile = false;
        this.label = '';
        this._isInitialized = false;
    }
    watchPropHandler() {
        this._handleDividers();
    }
    _handleDividers() {
        this._stepElements = this.host.querySelectorAll('c-step');
        const dividers = this.host.querySelectorAll('.divider');
        this._stepElements.forEach((item, index) => {
            item.current = index + 1 === +this.value;
            item.complete = index + 1 < +this.value;
            if (index + 1 < this._stepElements.length) {
                const div = this._isInitialized
                    ? dividers[index]
                    : document.createElement('div');
                div.classList.toggle('complete', !!item.complete);
                if (!this._isInitialized) {
                    div.classList.add('divider');
                    item.after(div);
                }
            }
            if (item.current) {
                this.label = item.textContent;
            }
        });
        this._isInitialized = true;
    }
    componentDidLoad() {
        this._handleDividers();
        this._resizeObserver = new ResizeObserver(([entry]) => {
            const maxWidth = this._stepElements.length * 180;
            this.isMobile = maxWidth > entry.contentRect.width;
            this.host.shadowRoot
                .querySelector('.c-steps')
                .classList.toggle('mobile', this.isMobile);
            this._stepElements.forEach((node) => {
                node.classList.toggle('mobile', this.isMobile);
            });
        });
        window.requestAnimationFrame(() => {
            this._resizeObserver.observe(this.host);
        });
    }
    _getA11yMessage(total, current) {
        return `
      Steps, step ${Math.min(current, total)} of ${total}.
      ${this.label}.
      ${current - 1} step${current - 1 !== 1 ? 's' : ''} marked as completed.
    `;
    }
    render() {
        return (h(Host, { key: '2b88cee8bdd6d69c81a667a1e4d008ea33e09b94', tabindex: "0" }, this._stepElements && (h("span", { key: 'bd512f57cf6ab6fec27b8a5a3bd1a8a5ff825700', class: "visuallyhidden" }, this._getA11yMessage(this._stepElements.length, +this.value))), h("div", { key: '6a4847a5f6fa86f01aa1143504b278a9f23f9509', class: "c-steps", "aria-hidden": "true" }, h("slot", { key: '1fdde35e7f63acde28a3b4aefdeddeba7629d143' })), this.isMobile && (h("div", { key: '55279c07864316d5c75fdbc96ae69ee69bdee415', class: "c-steps__label", "aria-hidden": "true" }, this.label))));
    }
    static get is() { return "c-steps"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-steps.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-steps.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Value of the accordion (current step number)"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isMobile": {},
            "label": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emit changes to the parent"
                },
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "watchPropHandler"
            }];
    }
}
//# sourceMappingURL=c-steps.js.map
