import { h, Host, } from "@stencil/core";
export class CSwiperTab {
    constructor() {
        this.disabled = false;
        this.active = false;
    }
    onTabClick(event) {
        if (this.active || this.disabled)
            return;
        this._rippleElement.createRipple(event, this._container);
        this.changeValue.emit(this.value);
    }
    render() {
        const classes = {
            'c-swiper-tab': true,
            'c-swiper-tab--active': !this.disabled && this.active,
            'c-swiper-tab--disabled': this.disabled,
        };
        const a11y = {
            'aria-selected': this.active ? 'true' : 'false',
            'aria-setsize': this.setsize,
            'aria-posinset': this.position,
            tabindex: this.active ? 0 : -1,
        };
        return (h(Host, Object.assign({ key: '3dbe445aaff07ede2070a14f032b52aca37ddf4c' }, a11y, { role: "tab" }), h("div", { key: 'acf35d9a5137175b09e63f137544b12541a4b5d6', id: this.hostId, class: classes }, h("div", { key: 'e2c0bfa034b78e7573467cdacfcff4d21c283d8c', class: "c-swiper-tab__content", ref: (el) => (this._container = el) }, h("div", { key: 'd6e94f1587b6f551d226e23d16685c9e16872f12', class: "c-swiper-tab__header" }, this.label, h("slot", { key: 'a158f8740fea910225134b197ad3b7ce3af763ae', name: "icon" })), h("div", { key: '82c9cd50f88f226898d94625d7ec5a6c693ccf07', class: "c-swiper-tab__description" }, h("slot", { key: '8d8369663a75ea6f5a66851948e8cf23a2f809ae' })), h("c-ripple", { key: '24ceb0bd3b3ca343c273647d0e1a0ff46e61f52b', ref: (el) => (this._rippleElement = el) })))));
    }
    static get is() { return "c-swiper-tab"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-swiper-tab.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-swiper-tab.css"]
        };
    }
    static get properties() {
        return {
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable button"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mark as active"
                },
                "getter": false,
                "setter": false,
                "attribute": "active",
                "reflect": false,
                "defaultValue": "false"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "setsize": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Size of the set"
                },
                "getter": false,
                "setter": false,
                "attribute": "setsize",
                "reflect": false
            },
            "position": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Position in the set"
                },
                "getter": false,
                "setter": false,
                "attribute": "position",
                "reflect": false
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Value of the button"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit value change to the parent"
                },
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get listeners() {
        return [{
                "name": "click",
                "method": "onTabClick",
                "target": undefined,
                "capture": false,
                "passive": true
            }];
    }
}
//# sourceMappingURL=c-swiper-tab.js.map
