import { h, } from "@stencil/core";
import { Swiper, Navigation } from "swiper";
import { mdiChevronLeft, mdiChevronRight } from "@mdi/js";
export class CSwiper {
    constructor() {
        this.isBeginning = true;
        this.isEnd = false;
        this.statusText = '';
        this._debounce = null;
    }
    onTabClick(event) {
        event.stopPropagation();
        this.value = event.detail;
        this._updateStatusText();
    }
    handleKeyUp(event) {
        const index = +event.target.dataset.index;
        const isArrowLeft = event.key === 'ArrowLeft';
        const isArrowRight = event.key === 'ArrowRight';
        const isBeginning = index === 0;
        const isEnd = index === this.slotItems.length - 1;
        if (!isArrowRight && !isArrowLeft)
            return;
        if (isArrowLeft) {
            if (isBeginning)
                return;
            this.value = this.slotItems[index - 1].value;
        }
        if (isArrowRight) {
            if (isEnd)
                return;
            this.value = this.slotItems[index + 1].value;
        }
        this._slideToTab(index - 1);
        this.slotItems.forEach((child) => {
            const isActive = child.value === this.value;
            if (isActive) {
                child.focus();
            }
        });
        this.changeValue.emit(this.value);
    }
    get id() {
        return this.elementId || `c-swiper--${CSwiper._uniqueId}`;
    }
    get slotItems() {
        return Array.from(this._wrapper.children);
    }
    _slideToTab(index) {
        this._swiper.slideTo(index);
        this._swiper.update();
    }
    componentDidLoad() {
        this._options = {
            modules: [Navigation],
            breakpointsBase: 'container',
            loop: false,
            speed: 300,
            slideToClickedSlide: true,
            slidesPerView: 1,
            spaceBetween: 8,
            threshold: 4,
            breakpoints: {
                480: {
                    slidesPerView: 2,
                },
                720: {
                    slidesPerView: 3,
                },
                960: {
                    slidesPerView: 4,
                },
            },
            navigation: {
                nextEl: '.c-icon-button--next',
                prevEl: '.c-icon-button--prev',
            },
            keyboard: true,
        };
        this._initializeSwiper();
    }
    _initializeSwiper() {
        var _a;
        for (const [index, slide] of this.slotItems.entries()) {
            slide.classList.add('swiper-slide');
            slide.setAttribute('data-index', index.toString());
            slide.value = (_a = slide.value) !== null && _a !== void 0 ? _a : index;
            slide.position = index + 1;
            slide.setsize = this.slotItems.length;
            if (slide.active) {
                requestAnimationFrame(() => {
                    this._slideToTab(index);
                });
            }
        }
        this._swiper = new Swiper(this._container, Object.assign({}, this._options));
        this._swiper.on('activeIndexChange', ({ isBeginning, isEnd }) => {
            this.isBeginning = isBeginning;
            this.isEnd = isEnd;
        });
    }
    _updateStatusText() {
        this.statusText = '';
        if (this._debounce !== null) {
            clearTimeout(this._debounce);
            this._debounce = null;
        }
        this._debounce = window.setTimeout(() => {
            var _a;
            const selection = (_a = this.slotItems) === null || _a === void 0 ? void 0 : _a.find((item) => item.value === this.value);
            this.statusText += `Currently selected - ${selection === null || selection === void 0 ? void 0 : selection.label}`;
            this._debounce = null;
        }, 1400);
    }
    componentWillLoad() {
        CSwiper._uniqueId += 1;
    }
    render() {
        return (h("div", { key: '201f2d65b4a8f1384f7621fb840c835c188f7d80', class: "c-swiper swiper" }, h("div", { key: 'bc28f328ddc3e1a2ad5bfca5d3acf9d88d3be55d', id: 'announce-' + this.id, class: "visuallyhidden", "aria-live": "polite", "aria-atomic": "true" }, this.statusText), h("div", { key: '27aeebbe6e05d5e370442650f63810032e1b8abe', class: "swiper-container", ref: (el) => (this._container = el) }, h("div", { key: '8a35faa991788a7a0df760ae914747434af589ff', role: "tablist", class: "swiper-wrapper", ref: (el) => (this._wrapper = el) }, h("slot", { key: '8cf057b9bad99a673181be305c34b25757c94838' })), h("div", { key: 'af7b0bf2eea8e4462eeeb13eb30be69e6bbe206f', class: "c-swiper__navigation" }, h("c-icon-button", { key: '62f6a239d83b4eab3afe33054c841636ae691712', "aria-disabled": this.isBeginning ? 'true' : 'false', "aria-label": "previous page", class: "c-icon-button--prev", disabled: this.isBeginning, size: "small", ghost: true }, h("span", { key: 'b53d3394a4397dbf7ad598d22353d359be690c19', class: "visuallyhidden" }, "Previous", h("span", { key: '9ad4925591289065688ff34d412e8c1363d09ac6' }, "page")), h("svg", { key: '0fefbf5a174996e6a3744a622f364a2e1e8104fd', width: "24", height: "24", viewBox: "0 0 24 24" }, h("path", { key: '8dedd11017e71763d87c1201966ed5b87ec7e0d6', d: mdiChevronLeft }))), h("c-icon-button", { key: '0f7f41ece6ca471aad6bf6f802d73c615d2f1a75', "aria-disabled": this.isEnd ? 'true' : 'false', "aria-label": "next page", class: "c-icon-button--next", disabled: this.isEnd, size: "small", ghost: true }, h("span", { key: 'c7ca70e6881ad2fecfdd48504d011127abe41416', class: "visuallyhidden" }, "Next", h("span", { key: 'd72874bb86167b846287b849cfeaa9ce6ebbceb7' }, "page")), h("svg", { key: 'b5bf75db8da3dee97c69c9cfcd1e113e5a9d6cbb', width: "24", height: "24", viewBox: "0 0 24 24" }, h("path", { key: '0d09a4b57777e3e025b2ce53e62327dee2d89387', d: mdiChevronRight })))))));
    }
    static get is() { return "c-swiper"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-swiper.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-swiper.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "any",
                "mutable": true,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Value of the swiper"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": true
            },
            "elementId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the swiper element"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isBeginning": {},
            "isEnd": {},
            "statusText": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emit value change to the parent"
                },
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                }
            }];
    }
    static get listeners() {
        return [{
                "name": "changeValue",
                "method": "onTabClick",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "keyup",
                "method": "handleKeyUp",
                "target": undefined,
                "capture": true,
                "passive": false
            }];
    }
}
CSwiper._uniqueId = 0;
//# sourceMappingURL=c-swiper.js.map
