import { h, } from "@stencil/core";
export class CSwitch {
    constructor() {
        this.checked = false;
        this.value = false;
        this.trueValue = true;
        this.falseValue = false;
        this.hostDisabled = false;
        this.loading = false;
        this.required = false;
        this.hasLabel = false;
        this._toggleState = () => {
            if (this.hostDisabled)
                return;
            this.checked = !this.checked;
            this.changeValue.emit(this.checked ? this.trueValue : this.falseValue);
            this.internals.setFormValue(this.checked ? this.trueValue.toString() : this.falseValue.toString());
        };
    }
    onValueChange(value) {
        this.checked = this.trueValue === value;
        this.internals.setFormValue(this.checked ? this.trueValue.toString() : this.falseValue.toString());
    }
    componentWillLoad() {
        this.checked = this.checked || this.value === this.trueValue;
        this.internals.setFormValue(this.checked ? this.trueValue.toString() : this.falseValue.toString());
    }
    componentDidLoad() {
        const slotted = this.host.childNodes;
        this.hasLabel = slotted && slotted.length > 0;
    }
    render() {
        const classes = {
            'c-switch': true,
            'c-switch--disabled': !!this.hostDisabled,
            'c-switch--label': this.hasLabel,
        };
        const sliderClasses = {
            'c-switch__slider': true,
            'c-switch__slider--disabled': !!this.hostDisabled,
            'c-switch__slider--loading': !!this.loading,
        };
        return (h("label", { key: '8edbf7e102d095f7f99f551194b5e8cc9cd4295e', class: classes, htmlFor: this.hostId }, h("div", { key: '9e9ee24c8bc184ae103d52d4f4bfaed7114f37ef', class: "c-switch__input" }, h("input", { key: '07c6760cb1f52fbac8cdd37c4eaf4d91a6885eb2', id: this.hostId, "aria-checked": this.checked.toString(), type: "checkbox", role: "switch", disabled: this.hostDisabled, checked: this.checked ? true : undefined, onChange: () => this._toggleState() }), h("span", { key: '4e9e0002bb766cbf7523a75fbeb7e39010391b71', class: sliderClasses }, h("c-spinner", { key: '95181bac9d370b8e478882e8032baa097e641223', size: 14, width: 2, color: "#fff" }))), this.hasLabel ? (h("div", { class: "c-switch__label" }, h("slot", null), this.required && h("span", { class: "required" }, "\u00A0*"))) : null));
    }
    static get is() { return "c-switch"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["c-switch.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-switch.css"]
        };
    }
    static get properties() {
        return {
            "checked": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the checkbox is selected."
                },
                "getter": false,
                "setter": false,
                "attribute": "checked",
                "reflect": false,
                "defaultValue": "false"
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "string | boolean",
                    "resolved": "boolean | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The input value\n- Only used when the checkbox participates in a native `<form>`"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false,
                "defaultValue": "false"
            },
            "trueValue": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "boolean | string",
                    "resolved": "boolean | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The value when the checkbox is checked"
                },
                "getter": false,
                "setter": false,
                "attribute": "true-value",
                "reflect": false,
                "defaultValue": "true"
            },
            "falseValue": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "boolean | string",
                    "resolved": "boolean | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The value when the checkbox is unchecked"
                },
                "getter": false,
                "setter": false,
                "attribute": "false-value",
                "reflect": false,
                "defaultValue": "false"
            },
            "hostDisabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "disabled"
                        }],
                    "text": "Disable the switch"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Loading state"
                },
                "getter": false,
                "setter": false,
                "attribute": "loading",
                "reflect": false,
                "defaultValue": "false"
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Id for the element"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set as required"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "hasLabel": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emit inner value change to parent"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "onValueChange"
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
//# sourceMappingURL=c-switch.js.map
