import { h, Host, } from "@stencil/core";
export class CTab {
    constructor() {
        this.active = false;
        this.disabled = false;
        this._onClick = (event, center = false) => {
            if (this.disabled)
                return;
            this._rippleElement.createRipple(event, this.element, center);
            this.tabChange.emit({ value: this.value, element: this.element });
        };
    }
    onTabFocus() {
        this.tabFocus.emit(this.value);
    }
    handleKeydown(event) {
        if (['Space', 'Enter'].includes(event.code)) {
            event.preventDefault();
            this._onClick(event, true);
        }
    }
    render() {
        const classes = {
            'c-tab': true,
            'c-tab--active': this.active,
            'c-tab--disabled': this.disabled,
        };
        const a11y = {
            'aria-disabled': this.disabled.toString(),
            'aria-hidden': this.disabled.toString(),
            'aria-selected': this.active.toString(),
            'aria-setsize': this.setsize,
            'aria-posinset': this.position,
            role: 'tab',
            tabindex: this.active && !this.disabled ? 0 : -1,
        };
        return (h(Host, Object.assign({ key: '580df1cd1a986e22b62b246c20b7fb70944ff5c9' }, a11y, { id: this.hostId, "data-value": this.value, class: classes, onClick: this._onClick }), h("div", { key: 'b9d2f3c21a5956da16793e49e96606fd2bb870b2', class: "c-tab__content" }, h("slot", { key: 'f3ebf35769eda15f880f2233d7df8840806a6715' })), h("c-ripple", { key: 'fcb039ef2716a2a452427e6321c185cb44f828f7', ref: (el) => (this._rippleElement = el) })));
    }
    static get is() { return "c-tab"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-tab.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-tab.css"]
        };
    }
    static get properties() {
        return {
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mark tab as active"
                },
                "getter": false,
                "setter": false,
                "attribute": "active",
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mark tab as disabled"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the tab"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "position": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Position in the set"
                },
                "getter": false,
                "setter": false,
                "attribute": "position",
                "reflect": false
            },
            "setsize": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Size of the set"
                },
                "getter": false,
                "setter": false,
                "attribute": "setsize",
                "reflect": false
            },
            "value": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Value for the tab\n- for use in c-tabs"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "tabChange",
                "name": "tabChange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit changes to the parent"
                },
                "complexType": {
                    "original": "{\n    value: number | string;\n    element: HTMLCTabElement;\n  }",
                    "resolved": "{ value: string | number; element: HTMLCTabElement; }",
                    "references": {
                        "HTMLCTabElement": {
                            "location": "global",
                            "id": "global::HTMLCTabElement"
                        }
                    }
                }
            }, {
                "method": "tabFocus",
                "name": "tabFocus",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "private",
                            "text": undefined
                        }],
                    "text": "Emit focus to the parent"
                },
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "element"; }
    static get listeners() {
        return [{
                "name": "focus",
                "method": "onTabFocus",
                "target": undefined,
                "capture": false,
                "passive": true
            }, {
                "name": "keydown",
                "method": "handleKeydown",
                "target": undefined,
                "capture": false,
                "passive": true
            }];
    }
}
//# sourceMappingURL=c-tab.js.map
