import { Host, h } from "@stencil/core";
export class CTable {
    constructor() {
        this.mobileBreakpoint = 600;
        this.responsive = false;
        this._createMobileLabels = () => {
            this.rows.forEach((row) => {
                const cells = Array.from(row.querySelectorAll('td'));
                let cellIndex = 0;
                cells.forEach((cell) => {
                    var _a;
                    const mobileLabel = cell.querySelector('.c-table__mobile-label');
                    if (mobileLabel)
                        return;
                    const span = document.createElement('span');
                    span.classList.add('c-table__mobile-label');
                    const heading = this.headers[+cellIndex % this.headers.length];
                    if (!heading)
                        return;
                    cellIndex += (_a = cell.colSpan) !== null && _a !== void 0 ? _a : 1;
                    span.innerHTML = heading;
                    cell.prepend(span);
                });
            });
        };
    }
    async updateMobileLabels() {
        this._createMobileLabels();
    }
    get cells() {
        return Array.from(this._tableElement.querySelectorAll('td'));
    }
    get rows() {
        return Array.from(this._tableElement.querySelectorAll('tr')).filter((row) => !row.hasAttribute('no-mobile-labels'));
    }
    get headers() {
        return Array.from(this._tableElement.querySelectorAll('th')).map((th) => th.innerHTML);
    }
    _handleResize(width) {
        const isMobile = width <= this.mobileBreakpoint;
        this._tableElement.classList.toggle('c-table--mobile', isMobile);
    }
    componentWillLoad() {
        this._tableElement = this.el.querySelector('table');
        this._tableElement.classList.add('c-table');
        this._observer = new ResizeObserver(([entry]) => {
            const { width } = entry.contentRect;
            this._handleResize(width);
        });
    }
    componentDidLoad() {
        if (this.responsive) {
            this._observer.observe(this._tableElement);
            this._createMobileLabels();
        }
    }
    disconnectedCallback() {
        this._observer.disconnect();
    }
    render() {
        return (h(Host, { key: 'dca16472d55f1864e58f178090f04b185df6cd8e' }, h("slot", { key: '42ca21af89b22919d324d0ae8f842e11f49f88b6' })));
    }
    static get is() { return "c-table"; }
    static get originalStyleUrls() {
        return {
            "$": ["c-table.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-table.css"]
        };
    }
    static get properties() {
        return {
            "mobileBreakpoint": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mobile breakpoint in pixels"
                },
                "getter": false,
                "setter": false,
                "attribute": "mobile-breakpoint",
                "reflect": false,
                "defaultValue": "600"
            },
            "responsive": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Should the table be responsive"
                },
                "getter": false,
                "setter": false,
                "attribute": "responsive",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get methods() {
        return {
            "updateMobileLabels": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "Update mobile labels after content change when using responsive table",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=c-table.js.map
