import { h, Host, } from "@stencil/core";
import { mdiCalendar, mdiEye, mdiEyeOff } from "@mdi/js";
export class CTextField {
    constructor() {
        this.automaticFocus = false;
        this.automaticCapitalize = '';
        this.autocorrect = '';
        this.autocomplete = '';
        this.disabled = false;
        this.hideDetails = false;
        this.hint = '';
        this.trimWhitespace = false;
        this.labelOnTop = false;
        this.max = null;
        this.min = null;
        this.readonly = false;
        this.required = false;
        this.rows = 1;
        this.shadow = false;
        this.step = null;
        this.type = 'text';
        this.valid = true;
        this.validate = false;
        this.validateOnBlur = false;
        this.validation = 'Required field';
        this.isFocused = false;
        this.labelWidth = 0;
        this.preSlotWidth = 0;
        this._originalType = '';
        this._handleChange = (event) => {
            if (this.type === 'number' && !event.target.value && event.key === '-') {
                return;
            }
            this.value = this.trimWhitespace
                ? event.target.value.trim()
                : event.target.value;
            this.changeValue.emit(this.value);
            this.internals.setFormValue(this.value);
        };
        this._handleBlur = (event) => {
            if (this.trimWhitespace) {
                const trimmedValue = event.target.value.trim();
                event.target.value = trimmedValue;
            }
        };
        this._togglePasswordVisibility = () => {
            if (this.disabled)
                return;
            this.type = this.type === 'password' ? 'text' : 'password';
        };
    }
    componentWillLoad() {
        CTextField._uniqueId += 1;
        this._originalType = this.type;
        this._inputId = `${(this.hostId ||
            this.label ||
            this.placeholder ||
            '').replace(/[^a-zA-Z0-9-_]/g, '')}_${CTextField._uniqueId}`;
        this.internals.setFormValue(this.value);
    }
    get isActive() {
        return !!this.value || this.isFocused;
    }
    get passwordIcon() {
        return this.type === 'password' ? mdiEye : mdiEyeOff;
    }
    _renderInputElement() {
        const props = {
            classes: {
                'c-input__input': true,
                'c-input__input--filled': !!this.value,
            },
            shared: {
                id: this._inputId,
                name: this.name,
                disabled: this.disabled,
                readonly: this.readonly,
                value: this.value,
                onInput: this._handleChange,
                onChange: this._handleChange,
                onBlur: this._handleBlur,
            },
            input: Object.assign(Object.assign(Object.assign({ type: this.type, min: this.min, max: this.max, step: this.step }, (!!this.autocomplete && { autocomplete: this.autocomplete })), (!!this.automaticCapitalize && {
                autocapitalize: this.automaticCapitalize,
            })), (!!this.autocorrect && { autocorrect: this.autocorrect })),
            textArea: {
                rows: this.rows,
            },
        };
        const textInput = (h("input", Object.assign({ class: props.classes }, props.input, props.shared, { ref: (el) => (this._inputElement = el) })));
        const textArea = (h("textarea", Object.assign({ class: props.classes }, props.shared, props.textArea)));
        return this.rows > 1 ? textArea : textInput;
    }
    _isFirefox() {
        return !!navigator.userAgent.match(/firefox|fxios/i);
    }
    _renderDateToggle() {
        if (this._originalType !== 'date' || this._isFirefox())
            return;
        const classes = {
            'c-input__date-toggle': true,
            'c-input__date-toggle--disabled': this.disabled,
        };
        return (h("svg", { class: classes, viewBox: "0 0 24 24", onClick: this._toggleDatepicker.bind(this) }, h("path", { d: mdiCalendar })));
    }
    _toggleDatepicker() {
        var _a;
        (_a = this._inputElement) === null || _a === void 0 ? void 0 : _a.showPicker();
    }
    _renderPasswordToggle() {
        if (this._originalType !== 'password')
            return;
        const classes = {
            'c-input__password-toggle': true,
            'c-input__password-toggle--disabled': this.disabled,
        };
        return (h("svg", { class: classes, viewBox: "0 0 24 24", onClick: this._togglePasswordVisibility }, h("path", { d: this.passwordIcon })));
    }
    render() {
        return (h(Host, { key: 'fc0f5d30cb6d8e7d96359300b79e568f4e4c5e7c' }, h("c-input", { key: '4e30200c8f46c36454023e42ad287f3ace86c2ec', autofocus: this.automaticFocus, disabled: this.disabled, "hide-details": this.hideDetails, hint: this.hint, id: this.hostId, "input-id": this._inputId, label: this.label, "label-on-top": this.labelOnTop, name: this.name, placeholder: this.placeholder, readonly: this.readonly, required: this.required, rows: this.rows, shadow: this.shadow, type: this.type, valid: this.valid, validate: this.validate, "validate-on-blur": this.validateOnBlur, validation: this.validation, value: this.value }, h("slot", { key: 'd0f32356c45e9b356bbace18f9b9ffaaded27d64', name: "pre", slot: "pre" }), this._renderInputElement(), this._renderPasswordToggle(), this._renderDateToggle(), h("slot", { key: '1e6eb44b3af9d9edb933bca28a2f60aefb0c9e1b', name: "post" }))));
    }
    static get is() { return "c-text-field"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["c-text-field.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["c-text-field.css"]
        };
    }
    static get properties() {
        return {
            "automaticFocus": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "autofocus"
                        }],
                    "text": "Auto focus the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "autofocus",
                "reflect": false,
                "defaultValue": "false"
            },
            "automaticCapitalize": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "autocapitalize"
                        }],
                    "text": "HTML input autocapitalize"
                },
                "getter": false,
                "setter": false,
                "attribute": "autocapitalize",
                "reflect": false,
                "defaultValue": "''"
            },
            "autocorrect": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "HTML input autocorrect"
                },
                "getter": false,
                "setter": false,
                "attribute": "autocorrect",
                "reflect": false,
                "defaultValue": "''"
            },
            "autocomplete": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "HTML input autocomplete"
                },
                "getter": false,
                "setter": false,
                "attribute": "autocomplete",
                "reflect": false,
                "defaultValue": "''"
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Disable the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "hideDetails": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hide the hint and error messages"
                },
                "getter": false,
                "setter": false,
                "attribute": "hide-details",
                "reflect": false,
                "defaultValue": "false"
            },
            "hint": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Hint text for the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "hint",
                "reflect": false,
                "defaultValue": "''"
            },
            "hostId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "name",
                            "text": "id"
                        }],
                    "text": "Id of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "id",
                "reflect": false
            },
            "trimWhitespace": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Trim whitespace from the return value"
                },
                "getter": false,
                "setter": false,
                "attribute": "trim-whitespace",
                "reflect": false,
                "defaultValue": "false"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false
            },
            "labelOnTop": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Label on top of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "label-on-top",
                "reflect": false,
                "defaultValue": "false"
            },
            "max": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Maximum value on a numeric input"
                },
                "getter": false,
                "setter": false,
                "attribute": "max",
                "reflect": false,
                "defaultValue": "null"
            },
            "min": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Minimum value on a numeric input"
                },
                "getter": false,
                "setter": false,
                "attribute": "min",
                "reflect": false,
                "defaultValue": "null"
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Name of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "placeholder": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Placeholder of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "placeholder",
                "reflect": false
            },
            "readonly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Mark as readonly"
                },
                "getter": false,
                "setter": false,
                "attribute": "readonly",
                "reflect": false,
                "defaultValue": "false"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the input as required"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            },
            "rows": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Rows on the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "rows",
                "reflect": false,
                "defaultValue": "1"
            },
            "shadow": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Shadow variant of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "shadow",
                "reflect": false,
                "defaultValue": "false"
            },
            "step": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Step size on a numeric input"
                },
                "getter": false,
                "setter": false,
                "attribute": "step",
                "reflect": false,
                "defaultValue": "null"
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Type of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false,
                "defaultValue": "'text'"
            },
            "valid": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Set the validity of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "valid",
                "reflect": false,
                "defaultValue": "true"
            },
            "validate": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Manual validation"
                },
                "getter": false,
                "setter": false,
                "attribute": "validate",
                "reflect": false,
                "defaultValue": "false"
            },
            "validateOnBlur": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Validate the input on blur"
                },
                "getter": false,
                "setter": false,
                "attribute": "validate-on-blur",
                "reflect": false,
                "defaultValue": "false"
            },
            "validation": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Custom validation message"
                },
                "getter": false,
                "setter": false,
                "attribute": "validation",
                "reflect": false,
                "defaultValue": "'Required field'"
            },
            "value": {
                "type": "string",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Value of the input"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isFocused": {},
            "labelWidth": {},
            "preSlotWidth": {}
        };
    }
    static get events() {
        return [{
                "method": "changeValue",
                "name": "changeValue",
                "bubbles": false,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emit changes to the parent"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hiddenEl"; }
    static get attachInternalsMemberName() { return "internals"; }
}
CTextField._uniqueId = 0;
//# sourceMappingURL=c-text-field.js.map
