import { p as proxyCustomElement, H, h, d as Host } from './p-Fv9YCUj3.js';
import { d as mdiCloseCircle } from './p-Bd7jq7MS.js';

const cMessageCss = "html{box-sizing:border-box}body{margin:0}*,*:before,*:after{box-sizing:inherit;-webkit-tap-highlight-color:transparent}:host{font-family:var(--c-font-family)}::-ms-reveal{display:none}:host{--_c-message-error-color:var(--c-message-error-color, var(--c-error-600));--_c-message-hint-color:var(--c-message-hint-color, var(--c-text-system));--_c-message-padding:var(--c-message-padding, 0 12px);display:block;line-height:1;padding:var(--_c-message-padding)}.c-message--active .c-message-item{opacity:1;transform:translateY(0)}.c-message-item{font-size:12px;min-height:16px;opacity:0;transform:translateY(-4px);transition:all 0.2s cubic-bezier(0.25, 0.8, 0.5, 1)}.c-message-item--hint{color:var(--_c-message-hint-color)}.c-message-item--error{color:var(--_c-message-error-color)}.c-message-item span{align-items:flex-start;color:currentColor;display:flex;gap:4px;min-height:16px}.c-message-item svg{fill:currentColor;height:16px;width:16px;position:relative;top:-2px;flex-shrink:0}.c-message .visuallyhidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;white-space:nowrap;width:1px}";

const CMessage = proxyCustomElement(class CMessage extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.hint = '';
        this.valid = true;
        this.validation = 'Required field';
        this.messageOptions = {
            show: true,
            type: 'hint',
            content: '',
        };
        this._validationIcon = (h("svg", { height: "16px", width: "16px", viewBox: "0 0 24 24" }, h("path", { d: mdiCloseCircle })));
    }
    onValidChange(valid) {
        this._handleValidation(valid);
    }
    onValidationMessageChange(message) {
        if (this.valid || !message)
            return;
        this.messageOptions = Object.assign(Object.assign({}, this.messageOptions), { content: (h("span", null, h("span", { class: "visuallyhidden" }, "Error: "), this._validationIcon, " ", message)) });
    }
    onHintMessageChange(message) {
        if (!this.valid || !message)
            return;
        this.messageOptions = Object.assign(Object.assign({}, this.messageOptions), { content: (h("span", null, h("span", { class: "visuallyhidden" }, "Hint: "), message)) });
    }
    _handleValidation(valid, timeout = 200) {
        this.messageOptions = Object.assign(Object.assign({}, this.messageOptions), { show: false });
        setTimeout(() => {
            this.messageOptions = Object.assign(Object.assign({}, this.messageOptions), { type: valid ? 'hint' : 'error', show: true, content: valid ? (h("span", { id: `hint-${this.inputId}` }, h("span", { class: "visuallyhidden" }, "Hint: "), this.hint)) : (h("span", { id: `error-${this.inputId}` }, this._validationIcon, h("span", { class: "visuallyhidden" }, "Error: "), this.validation)) });
        }, timeout);
    }
    componentDidLoad() {
        this._handleValidation(this.valid, 0);
    }
    render() {
        const classes = {
            'c-message': true,
            'c-message--active': this.messageOptions.show,
        };
        const messageClasses = {
            'c-message-item': true,
            [`c-message-item--${this.messageOptions.type}`]: true,
        };
        return (h(Host, { key: '83c81bba9bbbeb92a4a2ccfb66c481c66e16185d' }, h("div", { key: 'b934057f3e3b04b8a8f3965aa9faf515d39faea9', class: classes }, h("div", { key: '6f0e59f5cd2e42526facb5b2bf8fee23343da154', class: messageClasses }, this.messageOptions.content))));
    }
    static get watchers() { return {
        "valid": ["onValidChange"],
        "validation": ["onValidationMessageChange"],
        "hint": ["onHintMessageChange"]
    }; }
    static get style() { return cMessageCss; }
}, [1, "c-message", {
        "hint": [1],
        "inputId": [1, "input-id"],
        "valid": [4],
        "validation": [1],
        "messageOptions": [32]
    }, undefined, {
        "valid": ["onValidChange"],
        "validation": ["onValidationMessageChange"],
        "hint": ["onHintMessageChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["c-message"];
    components.forEach(tagName => { switch (tagName) {
        case "c-message":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CMessage);
            }
            break;
    } });
}

export { CMessage as C, defineCustomElement as d };
//# sourceMappingURL=p-BJVLvFq9.js.map

//# sourceMappingURL=p-BJVLvFq9.js.map