import { r as registerInstance, c as createEvent, h, g as getElement } from './index-gSzSMY-c.js';

const cModalCss = "html{box-sizing:border-box}body{margin:0}*,*:before,*:after{box-sizing:inherit;-webkit-tap-highlight-color:transparent}:host{font-family:var(--c-font-family)}::-ms-reveal{display:none}dialog.c-modal{background-color:transparent;border:none;color:var(--c-text-body);inset:0;margin:auto;max-width:calc(100% - 32px);overflow:visible;padding:0;width:var(--_c-modal-width, 600px)}dialog.c-modal:not([open]){pointer-events:none;opacity:0}dialog.c-modal::backdrop{background-color:transparent}dialog.c-modal--standalone::backdrop{background-color:rgba(0, 0, 0, 0.5)}dialog.c-modal--standalone.c-modal--backdrop-blur::backdrop{backdrop-filter:blur(4px)}@media (prefers-reduced-motion: no-preference){dialog.nudging{animation:dialog-nudge 0.15s cubic-bezier(0.25, 0.8, 0.25, 1) !important}dialog.opening{animation:dialog-open 0.3s cubic-bezier(0.25, 0.8, 0.5, 1) forwards}dialog.closing{animation:dialog-close 0.3s cubic-bezier(0.25, 0.8, 0.5, 1) forwards}}@keyframes dialog-nudge{0%{transform:scale(1)}50%{transform:scale(1.03)}100%{transform:scale(1)}}@keyframes dialog-open{from{transform:scale(0)}to{transform:scale(1)}}@keyframes dialog-close{to{transform:scale(0)}}";

const CModal = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.changeValue = createEvent(this, "changeValue", 3);
        this.value = false;
        this.dismissable = false;
        this.width = 600;
        this.zIndex = 10;
        this.disableBackdropBlur = false;
        this.innerValue = false;
        this.animateModal = false;
        this.standaloneMode = false;
        this._debounce = null;
        this._animationsDisabled = false;
        this._handleBackdrop = () => {
            var _a, _b, _c;
            const cMain = document.body.querySelector('c-main');
            if (!cMain) {
                this.standaloneMode = true;
                return;
            }
            this.standaloneMode = false;
            this._backdropElement || (this._backdropElement = cMain.shadowRoot.querySelector('c-backdrop'));
            if (!this._backdropElement) {
                return;
            }
            this._backdropElement.setAttribute('disable-backdrop-blur', this.disableBackdropBlur.toString());
            (_c = (_b = (_a = this._backdropElement) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelector('.c-backdrop')) === null || _c === void 0 ? void 0 : _c.classList.remove('closing');
        };
        this._handleShow = () => {
            requestAnimationFrame(() => {
                var _a, _b, _c, _d, _e, _f;
                this._handleBackdrop();
                if (!this._animationsDisabled) {
                    (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.addEventListener('animationend', this._onDialogOpened);
                    (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.add('opening');
                    (_e = (_d = (_c = this._backdropElement) === null || _c === void 0 ? void 0 : _c.shadowRoot) === null || _d === void 0 ? void 0 : _d.querySelector('.c-backdrop')) === null || _e === void 0 ? void 0 : _e.classList.add('opening');
                }
                (_f = this._dialog) === null || _f === void 0 ? void 0 : _f.showModal();
            });
        };
        this._onDialogOpened = () => {
            var _a, _b;
            (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.removeEventListener('animationend', this._onDialogOpened);
            (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.remove('opening');
        };
        this._handleClose = () => {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            if (this._animationsDisabled) {
                this._onDialogClosed();
                return;
            }
            (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.addEventListener('animationend', this._onDialogClosed);
            (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.add('closing');
            (_e = (_d = (_c = this._backdropElement) === null || _c === void 0 ? void 0 : _c.shadowRoot) === null || _d === void 0 ? void 0 : _d.querySelector('.c-backdrop')) === null || _e === void 0 ? void 0 : _e.classList.remove('opening');
            (_h = (_g = (_f = this._backdropElement) === null || _f === void 0 ? void 0 : _f.shadowRoot) === null || _g === void 0 ? void 0 : _g.querySelector('.c-backdrop')) === null || _h === void 0 ? void 0 : _h.classList.add('closing');
        };
        this._onDialogClosed = () => {
            var _a, _b, _c, _d, _e, _f;
            if (!this._animationsDisabled) {
                (_a = this._dialog) === null || _a === void 0 ? void 0 : _a.removeEventListener('animationend', this._onDialogClosed);
                (_b = this._dialog) === null || _b === void 0 ? void 0 : _b.classList.remove('closing');
                (_e = (_d = (_c = this._backdropElement) === null || _c === void 0 ? void 0 : _c.shadowRoot) === null || _d === void 0 ? void 0 : _d.querySelector('.c-backdrop')) === null || _e === void 0 ? void 0 : _e.classList.remove('closing');
            }
            (_f = this._dialog) === null || _f === void 0 ? void 0 : _f.close();
            if (!document.fullscreenElement)
                return;
            document.exitFullscreen();
        };
        this._handleClickOutside = () => {
            this._dialog.addEventListener('click', (e) => {
                if (e.clientX === 0 && e.clientY === 0)
                    return;
                const dialogDimensions = this._dialog.getBoundingClientRect();
                if (e.clientX < dialogDimensions.left ||
                    e.clientX > dialogDimensions.right ||
                    e.clientY < dialogDimensions.top ||
                    e.clientY > dialogDimensions.bottom) {
                    if (!this.dismissable) {
                        this._dialog.classList.add('nudging');
                        if (this._debounce !== null) {
                            clearTimeout(this._debounce);
                            this._debounce = null;
                        }
                        this._debounce = window.setTimeout(() => {
                            this._dialog.classList.remove('nudging');
                            this._debounce = null;
                        }, 150);
                        return;
                    }
                    this._handleClose();
                    this.changeValue.emit(false);
                }
            });
        };
        this._handleKeyDown = (e) => {
            if (e.keyCode === 27) {
                e.preventDefault();
                this._handleClose();
                this.changeValue.emit(false);
            }
        };
    }
    onValueChange(value) {
        if (value) {
            this._handleShow();
            return;
        }
        this._handleClose();
    }
    componentWillLoad() {
        this.innerValue = this.value;
        const width = isNaN(this.width) ? this.width : `${this.width}px`;
        this.el.style.setProperty('--_c-modal-width', `${width}`);
    }
    componentDidLoad() {
        const query = window.matchMedia('(prefers-reduced-motion: reduce)');
        this._animationsDisabled = query.matches;
        this._handleClickOutside();
        if (this.value) {
            this._handleShow();
        }
    }
    disconnectedCallback() {
        const dialogs = document.querySelectorAll('c-dialog');
        if (!dialogs.length) {
            this._handleClose();
        }
    }
    render() {
        const dialogStyle = {
            'z-index': `${this.zIndex}`,
        };
        const classes = {
            'c-modal': true,
            'c-modal--standalone': this.standaloneMode,
            'c-modal--backdrop-blur': !this.disableBackdropBlur,
        };
        return (h("dialog", { key: '8de37abe52c89f3809ffea04150c029feea47f90', ref: (el) => (this._dialog = el), style: dialogStyle, class: classes, onKeyDown: this._handleKeyDown }, h("slot", { key: '086797c254e2778bbbe74d4776fe6ce931d738cb' })));
    }
    get el() { return getElement(this); }
    static get watchers() { return {
        "value": ["onValueChange"]
    }; }
};
CModal.style = cModalCss;

export { CModal as c_modal };
//# sourceMappingURL=c-modal.entry.js.map

//# sourceMappingURL=c-modal.entry.js.map